from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "wide_container")

variables = {
    "container-sm": "768",
    "container-md": "991",
    "container-lg": "1200",
    "container-xl": "1600",
    "container-xxl": "1800",
}
