.btn-dropdown{
    .dropdown-menu{
        .dropdown-item{
            display: flex;
            align-content: center;
            justify-content: space-between;
            .dropdown-text{
                @extend .btn;
                padding-left:0;
            }
            .dropdown-btn{
                @extend .ms-3;
            }
        }
    }
}