// Bootstrap variables/settings
$enable-important-utilities: false;
$variable-prefix:             bs-;

// colors
$primary:     ocyancolor("primary");
$success:     ocyancolor("success");
$info:        ocyancolor("info");
$danger:      ocyancolor("danger");
$warning:     ocyancolor("warning");
$light:       ocyancolor("light");
$secondary:   ocyancolor("secondary");
$white:       ocyancolor("white");
$price-color: ocyancolor("price-color");
$gray-100:    ocyancolor("gray-100");
$gray-200:    ocyancolor("gray-200");
$gray-300:    ocyancolor("gray-300");
$gray-400:    ocyancolor("gray-400");
$gray-500:    ocyancolor("gray-500");
$gray-600:    ocyancolor("gray-600");
$gray-700:    ocyancolor("gray-700");
$gray-800:    ocyancolor("gray-800");
$gray-900:    ocyancolor("gray-900");
$black:       ocyancolor("black");

// Body settings
$body-bg:     ocyancolor("body-background");
$body-color:  ocyancolor("body-color");

// Footer settings
$footer-bg:     ocyancolor("footer-background");

// Header settings
$pagemenu-full-width: ocyanvariable("pagemenu-full-width");
$justify-search: ocyanvariable("justify-search");
$header-background: ocyancolor("header-background");
$header-sticky: ocyanvariable("sticky-header");
$basket-counter: ocyancolor("basket-counter-background");
$search-background: ocyancolor("search-background");
$no-padding-header: ocyanvariable("no-padding-header");
$header-type: ocyanvariable("header");

// Header ordering
$order-logo: ocyanbarenumber("order-logo");
$order-products: ocyanbarenumber("order-products");
$order-pages: ocyanbarenumber("order-pages");
$order-search: ocyanbarenumber("order-search");
$order-user: ocyanbarenumber("order-user");
$order-basket: ocyanbarenumber("order-basket");

// spacing
$spacer: ocyannumber("spacer", "rem");
$grid-gutter-width: ocyannumber("grid-gutter-width", "rem")!default;
$container-max-widths: (
  sm: ocyannumber("container-sm", "px"),
  md: ocyannumber("container-md", "px"),
  lg: ocyannumber("container-lg", "px"),
  xl: ocyannumber("container-xl", "px"),
  xxl: ocyannumber("container-xxl", "px"),
) !default;
$grid-breakpoints: (
  xs: 0,
  sm: ocyannumber("container-sm", "px"),
  md: ocyannumber("container-md", "px"),
  lg: ocyannumber("container-lg", "px"),
  xl: ocyannumber("container-xl", "px"),
  xxl: ocyannumber("container-xxl", "px")
) !default;

$header-type: ocyanvariable("header");

// font settings
$font-family-base: var(--#{$variable-prefix}#{ocyanvariable("font-family-base")});
$font-size-base: ocyannumber("font-size-base", "rem");
$line-height-base: ocyanbarenumber("line-height-base");

$font-family-sans-serif: ocyanlist("font-family-sans-serif");
$font-family-monospace: ocyanlist("font-family-monospace");
$header-font-family: ocyanlist("header-font-family");
$font-weight-bold: ocyanbarenumber("font-weight-bold");
$headings-font-weight: ocyanbarenumber("font-weight-headers");
$headings-font-style: ocyanvariable("headings-font-style");
$font-weight-normal: ocyanvariable("font-weight-normal");

$font-size-root: ocyannumber("font-size-root", "rem");

// borders
$border-width: ocyannumber("border-width", "px");
$border-radius: ocyannumber("border-radius", "rem");
$border-radius-sm: ocyannumber("border-radius", "rem");
$border-radius-lg: ocyannumber("border-radius", "rem");

// product options
$product-border-width: ocyannumber("product-border-width", "px");
$product-padding: ocyannumber("product-padding", "rem");
$product-shadow: ocyanvariable("product-shadow");
$product-rating: ocyanvariable("product-rating");

// image size
$image-min-height: ocyannumber("image-min-height", "px");

// category_navigation_depth
$max-category-depth: ocyanbarenumber("max-category-depth");

// Button tekst contrast ratio
$min-contrast-ratio:   2.5;

$promo-background: ocyancolor("promo-background");

$grid-gutter-height: 6rem;
