{% load sorl_thumbnail ocyan_thumbnail %}
{% retina thumb 1.5 options=options as android %}
{% retina thumb 2 options=options as iphone %}
<source class="owl-lazy tns-lazy-img" {% if type %}type="{{ type }}"{% endif %} data-srcset="{{ thumb.url }}, {{ android.url }} 1.5x, {{ iphone.url }} 2x"></source>