{% extends "oscar/basket/basket.html" %}

{% load thumbnail %}
{% load i18n %}

{% block extrahead %}
<meta name="robots" content="noindex">
{{ block.super }}
{% endblock %}

{% block breadcrumbs %}{% endblock %}
{% block header_breadcrumbs %}{% endblock %}