{% extends "oscar/communication/notifications/detail.html" %}
{% load i18n %}

{% block tabcontent %}
<table class="table table-striped table-bordered">
    {% if notification.sender %}
    <tr>
        <th>{% trans 'Sender' %}</th>
        <td>{{ notification.sender }}</td>
    </tr>
    {% endif %}
    <tr>
        <th>{% trans 'Date sent' %}</th>
        <td>{{ notification.date_sent }}</td>
    </tr>
    {% if notification.body %}
    <tr>
        <th>{% trans 'Subject' %}</th>
        <td>{{ notification.subject|safe }}</td>
    </tr>
    <tr>
        <th>{% trans 'Body' %}</th>
        <td>{{ notification.body }}</td>
    </tr>
    {% else %}
    <tr>
        <th>{% trans 'Message' %}</th>
        <th>{{ notification.subject|safe }}</th>
    </tr>
    {% endif %}
</table>
<div class="form-group form-actions"><a href="{% url 'customer:notifications-inbox' %}" class="btn btn-secondary">{% trans 'Return to notifications inbox' %}</a></div>
{% endblock tabcontent %}