{% extends "oscar/customer/wishlists/wishlists_delete.html" %}
{% load i18n %}

{% block tabcontent %}
<form method="post">
    {% csrf_token %}
    <p>
{% blocktrans with name=wishlist.name %}Are you sure you want to delete {{ name }}?{% endblocktrans %}
    </p>

    <div class="form-group form-actions">
        <button type="submit" class="btn btn-danger" data-loading-text="{% trans 'Deleting...' %}">{% trans 'Delete' %}</button> {% trans 'or' %} <a href="{% url 'customer:wishlists-list' %}">{% trans 'cancel' %}</a>
    </div>
</form>
{% endblock tabcontent %}