{% load i18n %}
<h3 class="text-center">{{self.title}}</h3>
<hr>
<form id="contact-form" method="post" action="{% url 'contact_form:contact-form-handler' %}">
    {% csrf_token %}
    <div class="controls">
        <div class="row">
            {% for field in form %}
            <div class="col-lg-12">
                {% include 'oscar/partials/form_field.html' with field=field placeholder=field.field.widget.attrs.placeholder %}
            </div>
            {% endfor %}
            <div class="col-lg-12">
                <input type="submit" class="btn btn-primary btn-send" value="{% trans 'Submit' %}">
            </div>
        </div>
    </div>
</form>