from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "page_above_header")

variables = {
    "order-logo": "2",
    "order-products": "3",
    "order-pages": "1",
    "order-search": "4",
    "order-user": "5",
    "order-basket": "6",
    "pagemenu-full-width": "true",
    "justify-search": "true",
}
