.oxyan-carousel{
	@extend .tns-slider;
	.oxyan-carousel-item{
		position: relative;
		.slider-body{
			position: absolute;
			bottom: 0;
			left: 50%;
			transform: translateX(-50%);
			width: 100%;
			max-width: 800px;
			@extend .p-3;
		}
		img{
			width: 100%;
			height: auto;
		}
	}
}