{% load styling_tags wagtailimages_tags ocyan_thumbnail %}

<div class="oxyan-carousel">
    {% for slide in self %}
    <div class="slider-item oxyan-carousel-item {% if forloop.first %}active{% endif %}">
        {% if forloop.first %}
        {% focuspoint_picture slide.image %}
        {% else %}
        {% lazy_tns_focuspoint_picture slide.image %}
        {% endif %}

    	{% if slide.caption %}
    	<div class="slider-body" {% get_styling slide.styling %}>
            <div class="slider-body-inner">
    			{{ slide.caption|convert_to_html }}
            </div>
        </div>
        {% endif %}
    </div>
    {% endfor %}
</div>