.custom-simple-carousel{
	@extend .tns-slider;
	.item-link{
		display: block;
		text-align: center;
		text-decoration: unset;
		padding: .5rem;
		span{
			display: block;
			margin-top: .5rem;
			color: $black;
			font-size: 1.25rem;
			font-weight: 600;
		}
	}
	img{
		width: 100%;
		height: auto;
		padding: .5rem;
	}
}