@import "slideshow";
@import "category_block";
@import "contact_block";
@import "embed_video";
@import "highlight_slider";
@import "icon_slider";
@import "oxyan_carousel";
@import "parallax";
@import "popup";
@import "store_locator";
@import "product_slider";
@import "table_block";

.parallax{
	a{
		color: inherit;
	}
}

img{
	border-radius: $border-radius;
}

.tns-slider{
	&:not(.tns-carousel){
		display: flex;
		flex-direction: row;
		flex-wrap: nowrap;
		overflow: hidden;
		.slider-item, .dots, .item-link, .product-carousel-item{
			min-width: 100%;
			display: block;
		}
		a{
			animation: none;
		}
	}
}