@import "footer";
@import "breadcrumbs";
@import "dropdown";
@import "header";
@import "theme_switcher";
@import "promo_header";
@import "header_goods";
@import "wagtail_search";
@import "header_commerce";
@if $header-type == "goods" {
	@include header_goods_styles();
} @else if $header-type == "commerce" {
	@include header_commerce_styles();
}

header{
	context: $header-type;
}

.btn{
	font-weight: 600;
	padding: .5rem 1.5rem;
}