@mixin basket-totals-wrapper{
    @extend .bg-light, .p-4;
    border-radius: .3rem;
    .basket-totals{
        @extend .my-3;
        .totals-table{
            td, th{
                padding: .3rem 0;
            }
            td{
                opacity: .8;
                font-size: 1rem;
            }
            th.total{
                font-size: 1.35rem;
                font-weight: 700;
                @extend .pt-4;
            }
            .table-border{
                td{
                    padding: .7rem 0;
                    position: relative;
                    &:after{
                        content: "";
                        width: 100%;
                        position: absolute;
                        top: 50%;
                        left: 0;
                        transform: translateY(-50%);
                        border-bottom: 1px solid $border-color;
                    }
                }
            }
        }
    }
}