from django.utils.translation import pgettext_lazy

from ocyan.core.fender import config

display_name = pgettext_lazy("theme switcher", "header_footer_contrast")
primary = config.get("themes", "primary")
headerBackground = config.get("themes", "header-background", primary)
footerBackground = config.get("themes", "footer-background", headerBackground)

headerColor = config.get("themes", "header-link-color", "#fff")
footerColor = config.get("themes", "footer-color", headerColor)

variables = {
    "header-background": headerBackground,
    "header-link-color": headerColor,
    "header-heading-color": headerColor,
    "footer-background": footerBackground,
    "basket-counter-background": "#ff6600",
    "footer-color": footerColor,
    "border-width": 0,
    "search-background": "#fff",
}
