"""
This file defines the default values for all variables that can be altered
in specific templates
"""

from django.utils.translation import pgettext_lazy

from ocyan.core.fender import config

display_name = pgettext_lazy("theme switcher", "default")
primary = config.get("themes", "primary", "#0090e3")
basket_counter_background = config.get("themes", "basket-counter-background", primary)

variables = {
    # colors, try changing the white and black color and see what happens
    "primary": primary,
    "secondary": "#6c757d",
    "info": "#0dcaf0",
    "success": "#198754",
    "danger": "#dc3545",
    "warning": "#ffc107",
    "white": "#ffffff",
    "light": "#f8f9fa",
    "gray-100": "#f8f9fa",
    "gray-200": "#e9ecef",
    "gray-300": "#dee2e6",
    "gray-400": "#ced4da",
    "gray-500": "#adb5bd",
    "gray-600": "#6c757d",
    "gray-700": "#495057",
    "gray-800": "#343a40",
    "gray-900": "#212529",
    "black": "#000000",
    "price-color": "#212529",
    # Coyote variable
    "row-spacer": "3",
    # borders
    "border-width": 1,
    "border-radius-lg": 0,
    "border-radius": 0,
    "body-background": "#fff",
    "body-color": "#212529",
    # stefan weet dit setting
    "max-category-depth": 5,
    "image-min-height": 305,
    "thumbnail_geometry": "305x305",
    "footer-background": "#f8f9fa",
    "header-background": "#fff",
    "promo-background": "#fff",
    "no-padding-header": "false",
    "basket-counter-background": basket_counter_background,
    "search-background": "#e9ecef",
    "product-border-width": 0,
    "product-padding": 0,
    "product-shadow": "false",
    "product-rating": "true",
    "sticky_header": "false",
    "pagemenu-full-width": "false",
    "justify-search": "false",
    # no idea
    "order-logo": 1,
    "order-products": 2,
    "order-pages": 3,
    "order-search": 4,
    "order-user": 5,
    "order-basket": 6,
    # layout and spacing settings see https://getbootstrap.com/docs/5.0/layout/gutters/#change-the-gutters
    "spacer": 1,
    "grid-gutter-width": 1,
    "container-sm": 540,
    "container-md": 720,
    "container-lg": 960,
    "container-xl": 1140,
    "container-xxl": 1320,
    # font settings, zie https://getbootstrap.com/docs/5.0/content/typography/
    "font-size-root": 1,
    "font-family-base": "font-sans-serif",
    "font-size-base": 1,
    "line-height-base": 1.5,
    "font-weight-bold": 600,
    "font-weight-headers": 600,
    "headings-font-style": "normal",
    "header-font-family": [
        "system-ui",
        "-apple-system",
        '"Segoe UI"',
        "Roboto",
        '"Helvetica Neue"',
        "Arial",
        '"Noto Sans"',
        '"Liberation Sans"',
        "sans-serif",
        '"Apple Color Emoji"',
        '"Segoe UI Emoji"',
        '"Segoe UI Symbol"',
        '"Noto Color Emoji"',
    ],
    "font-family-sans-serif": [
        "system-ui",
        "-apple-system",
        '"Segoe UI"',
        "Roboto",
        '"Helvetica Neue"',
        "Arial",
        '"Noto Sans"',
        '"Liberation Sans"',
        "sans-serif",
        '"Apple Color Emoji"',
        '"Segoe UI Emoji"',
        '"Segoe UI Symbol"',
        '"Noto Color Emoji"',
    ],
    "font-family-monospace": [
        "SFMono-Regular",
        "Menlo",
        "Monaco",
        "Consolas",
        '"Liberation Mono"',
        '"Courier New"',
        "monospace",
    ],
}
