.privacy-wrapper{
	background: $gray-200;
	min-height: 60vh;
	display: flex;
	flex-direction: column;
	justify-content: space-around;
	align-items: center;
	.login-wrapper{
		box-shadow: 0 10px 20px -10px rgba(0,0,0,.2);
		background: $white;
		padding: 2rem;
		border-radius: $border-radius;
		.login-header{
			@extend .h4, .mb-4;
		}
		.icon_wrapper{
			.form-group{
				& > div{
					position: relative;
					&:after{
						font: normal normal normal 14px/1 'Highbiza';
						position: absolute;
						top: 50%;
						right: .75rem;
						transform: translateY(-50%);
						color: $gray-500;
					}
				}
			}
			&.username{
				.form-group{
					& > div{
						&:after{
							content: "\f07b";
						}
					}
				}
			}
			&.password{
				.form-group{
					& > div{
						&:after{
							content: "\f07c";
						}
					}
				}
			}
		}
		.form-group{
			@extend .mb-3;
		}
		.login-footer{
			@extend .mt-4;
			display: flex;
			align-items: center;
			justify-content: flex-end;
			width: 100%;
			button{
				@extend .ms-3;
				i{
					@extend .ms-2, .small;
				}
			}
		}
	}
}