{% extends "checkout/partials/totals_block.html" %}

{% load i18n delivery_time ocyanjson %}

{% block panel_header %}
	<div class="panel-header">
		<h3>{% trans "Totals" %}</h3>
	</div>
{% endblock %}

{% block panel_body %}
	<div id="checkouttotal">
	    {% delivery_time basket as deliverytime %}
	    {% if deliverytime %}
		    <div id="basket_totals" class="w-100">
		        <div class="delivery_time">
		            <i class="fa fa-info-circle"></i>
		            <div class="time_wrapper">
		            	{{ deliverytime|safe }}
		            </div>
		        </div>
		    </div>
	    {% endif %}
		<div class="nav-item product-line">
			{% include "oscar/basket/partials/basket_totals.html" %}
		</div>
	</div>

    {% block vat_regulation %}
      {{ block.super }}
    {% endblock %}
{% endblock %}
