{% load currency_filters %}
{% load i18n %}
{% load purchase_info_tags %}

{% purchase_info_for_product request product as session %}

<div class="stock_price">
    {% if session.price.from_price %}
        <span class="from_price">
            {{ session.price.from_price.incl_tax|currency:session.price.currency }}
        </span>
    {% elif product.attr.from_price %}
    <span class="from_price">
        {{ product.attr.from_price|currency:session.price.currency }}
    </span>
    {% endif %}
    {% if session.price.exists %}
    {% if session.price.excl_tax == 0 %}
    <span data-price="{% trans 'Free' %}" data-amount="0">{% trans "Free" %}</span>
    {% elif session.price.is_tax_known %}
    {% include "oscar/catalogue/partials/price.html" %}
    {% else %}
    <span class="first-session-price price_excl_tax" data-price="{{ session.price.base_price.excl_tax|currency:session.price.currency }}" data-amount="{{ session.price.base_price.excl_tax }}">{{ session.price.excl_tax|currency:session.price.currency }}</span>
    {% endif %}
    {% endif %}
</div>