{% load i18n %}
{% load display_tags %}

<li class="nav-item">
    <a href="{% url 'customer:profile-view' %}" class="nav-link{% if active_tab == 'profile' %} active{% endif %}"><i class="fa fa-user-solid"></i> {% trans "Profile" %}</a>
</li>
<li class="nav-item">
    <a href="{% url 'customer:order-list' %}" class="nav-link{% if active_tab == 'orders' %} active{% endif %}"><i class="fa fa-tags-solid"></i> {% trans "Order History" %}</a>
</li>
{% iffeature 'wishlists' %}
<li class="nav-item">
    <a href="{% url 'customer:wishlists-list' %}" class="nav-link{% if active_tab == 'wishlists' %} active{% endif %}"><i class="fa fa-star-solid"></i> {% trans "Wish Lists" %}</a>
</li>
{% endiffeature %}
<li class="nav-item">
    <a href="{% url 'customer:address-list' %}" class="nav-link{% if active_tab == 'addresses' %} active{% endif %}"><i class="fa fa-address-book-solid"></i> {% trans "Address Book" %}</a>
</li>
<li class="nav-item">
    <a href="{% url 'customer:email-list' %}" class="nav-link{% if active_tab == 'emails' %} active{% endif %}"><i class="fa fa-paper-plane-solid"></i> {% trans "Email History" %}</a>
</li>
<li class="nav-item">
    <a href="{% url 'customer:alerts-list' %}" class="nav-link{% if active_tab == 'alerts' %} active{% endif %}"><i class="fa fa-inbox-solid"></i> {% trans "Product Alerts" %}</a>
</li>
<li class="nav-item">
    <a href="{% url 'customer:notifications-inbox' %}" class="nav-link{% if list_type == 'inbox' %} active{% endif %}"><i class="fa fa-bell-solid"></i> {% trans "Notifications" %}</a>
</li>
<li class="nav-item">
    <a href="{% url 'customer:notifications-archive' %}" class="nav-link{% if list_type == 'archive' %} active{% endif %}"><i class="fa fa-archive-solid"></i> {% trans 'Archive' context 'noun' %}</a>
</li>
<li class="nav-item">
    <a href="{% url 'customer:logout' %}" class="nav-link"><i class="fa fa-logout"></i> {% trans "Logout" %}</a>
</li>