{% extends "oscar/catalogue/partials/product.html" %}

{% load ocyan_thumbnail i18n ocyanjson wagtailcore_tags reviews_tags purchase_info_tags display_tags %}

{% block product_price %}
{{block.super}}

<div class="wishlist-actions">
    <a class="text-primary" href="{% url 'customer:wishlists-remove-product' key=wishlist.key line_pk=line.pk %}"><i class="fa fa-trash"></i></a>

    <div class="dropdown">
        <a class="text-primary wishlist-option-button" data-bs-toggle="dropdown" aria-expanded="false">
            <i class="fa fa-exchange"></i>
        </a>
        <ul class="dropdown-menu dropdown-menu-right">
            <li>
                <a href="{% url 'customer:wishlists-remove-product' key=wishlist.key line_pk=line.pk %}" class="dropdown-item">
                    {% trans 'Remove' %}
                </a>
            </li>
            {% for other_wishlist in other_wishlists %}
            <li>
                <a href="{% url 'customer:wishlists-move-product-to-another' key=wishlist.key line_pk=line.pk to_key=other_wishlist.key %}" class="dropdown-item">
{% blocktrans with name=other_wishlist.name %}Move to '{{ name }}' wish list{% endblocktrans %}
                </a>
            </li>
            {% endfor %}
        </ul>
    </div>
</div>
{% endblock %}