.all-stores{
	.stores-bar{
		border: 0;
		border-radius: $border-radius-lg;
		display: flex;
		align-items: center;
		position: relative;
		overflow: hidden;
		justify-content: flex-start;
		@extend .mb-3, .bg-light, .py-2;
		.location-input{
			display: flex;
			align-items: flex-end;
			width: 100%;
			@extend .pe-3;
			label{
				display: none;
			}
			.pipe{
				height: 2rem;
				width: 1px;
				background: $gray-400;
				@extend .mx-2;
			}
			input#id_address, select#id_radius{
				margin-left: 0;
				height: 100%;
				border: 0;
				border-radius: 0;
				background: transparent;
				box-shadow: unset;
				outline: unset;
				border-bottom: 1px solid $gray-300;
				@extend .py-2;
			}
			input#id_address{
				width: 100%;
				@extend .me-3;
			}
		}
		.current-location, .search-radius{
			font-size: 1.25rem;
			@extend .px-3;
		}
	}
	#google-store-map{
		border-radius: $border-radius-lg;
		overflow: hidden;
	}
	.store-items{
		display: flex;
		flex-direction: column;
		@extend .mt-3, .mt-lg-0;
		.store-item{
			width: 100%;
			max-width: 100%;
			.store-info{
				width: 100%;
				height: 100%;
				border: 0;
				border-radius: $border-radius-lg;
				background: $gray-100;
				transition: .2s ease;
				@extend .p-3, .mb-3;
				&:hover{
					background: $gray-200;
				}
				.dealer-card{
					width: 100%;
					display: flex;
					.dealer-card-inner{
						display: flex;
						flex-direction: column;
						width: 100%;
						.card-title{
							@extend .mb-0;
						}
						.dealer-info{
							display: flex;
							align-items: center;
							@extend .small, .text-muted;
							i{
								@extend .me-1;
							}
						}
						.dealer-links{
							@extend .mt-2;
							.badge{
								color: $white !important;
							}
						}
					}
					.dealer-directions{
						margin: auto 0;
						a{
							white-space: nowrap;
							border-radius: $border-radius-lg;
							i{
								@extend .mb-1;
								font-size: 1.5rem;
							}
							small{
								font-size: .75rem;
								padding: .25rem;
								padding-bottom: 0;
								display: block;
							}
						}
					}
				}
			}
		}
	}
	#reset-map{
		@extend .px-0, .text-primary, .my-3, .my-lg-0;
	}
	#search-radius, #reset-map{
		box-shadow: none;
		outline: unset;
		background: transparent;
		border: 0;
	}
}