{% extends "oxyan/headers/header.html" %}
{% load currency_filters i18n oxyan category_tags ocyanjson cache %}


{% block category_menu %}
{% cache 300 header_mega_menu LANGUAGE_CODE request.site %}
{% ocyanjson "theme" "menu_depth" 1 as menu_depth %}
{% category_tree depth=menu_depth as category_tree_items %}
<div class="collapse navbar-collapse menu-bar product-menu-bar" id="navbarSupportedContent">
    <ul class="navbar-nav">
        <li class="nav-item dropdown {% if menu_depth > 1 %}position-unset{% endif %}">
            <button class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
            {% trans "All products" %}
            </button>
            <ul class="dropdown-menu icon-dropdown" aria-labelledby="navbarDropdown" id="navbarDropdown">
                {% include "oxyan/partials/icon_dropdown.html" with menu_items=category_tree_items mega_menu=True dropdown=True %}
                <li class="nav-item all-products"><a class="nav-link" href="{% url 'catalogue:index' %}">{% trans "All products" %} <i class="fa fa-chevron-right"></i></a></li>
            </ul>
        </li>
    </ul>
</div>
{% endcache %}
{% endblock %}