{% load i18n %}

<form method="get" rel="search" action="{% url 'search:search' %}" class="form-inline search_form" id="search_form">
    <div class="search-input-wrapper">
        <input type="search" name="q" placeholder="{% trans 'Search' %}" tabindex="-1" class="form-control" autocomplete="off" required="" id="id_q" title="{% trans 'Search' %}">
        <button class="search_submit" aria-label="Search button" title="{% trans 'Search icon and submit button' %} button" tabindex="-1"><i class="fa fa-search"></i></button>
    </div>
</form>
