.sidebar{
    h2{
        @extend .mb-3;
    }
}

.nav-category{
    ul {
        @extend .list-unstyled;
        li { 
            a {
                @extend .pb-1;
                display: block;
                color: $dark;
                text-decoration: unset;
                &.active {
                    font-weight: $font-weight-bold;
                }
            }
            &.last{
                @extend .mb-2;
            }
        }
    }
    .depth-1 > a {
        font-weight: $font-weight-bold;
    }
    @for $i from 2 through $max-category-depth {
      .depth-#{$i} {
        padding-left: map-get($spacers, 2) * ($i - 1);
      }
    }
}

.cat-image{
    width: 100%;
    height: 175px;
    img{
        width: 100%;
        height: 175px !important;
        object-fit: cover;
    }
}