{% load category_tags oxyan %}
{% category_tree parent=tree_category.category depth=category.depth as sub_tree_categories %}

{% for sub_tree_category, info in sub_tree_categories %}
{% if sub_tree_category|is_selected:category %}
<li class="depth-{{ sub_tree_category.depth }} {% if forloop.last %}last{% endif %}">
    <a class="{% if sub_tree_category.pk == category.pk %}active{% endif %}" href="{{ sub_tree_category.get_absolute_url }}">{{ sub_tree_category.name }}</a>
{% endif %}
{% endfor %}
