::selection{
	border: 1px solid var(--bs-primary);
}

button, a{
	touch-action: manipulation;
}

.user-is-tabbing{
	*:not(input):focus-visible {
		transition: .1s;
		outline: 2px var(--bs-primary) solid !important;
		border: 0 !important;
		box-shadow: unset !important;
		filter: unset;
	}

	input:focus-visible, .btn:focus-visible{
		transition: .1s;
		outline: 2px var(--bs-primary) solid !important;
		border: 0 !important;
		box-shadow: unset !important;
	}
}

header{
	.menu-bar{
		.dropdown{
			&.open{
				.dropdown-menu{
					display: block !important;
				}
			}
		}
	}
}

.hidelink {
	position: absolute;
	left: 50%;
	top: 1rem;
	z-index: 999999999999999;
	transform: translateY(-200%) translateX(-50%);
	transition: .4s ease !important;
	&.showlink, &:focus {
		transform: translateY(0) translateX(-50%);
	}
}
