{% load ocyan_thumbnail wagtailimages_tags styling_tags sorl_thumbnail %}


{% thumbnail self.image.file "1920" upscale=False format="JPEG" as image %}
{% thumbnail self.image.file "768" upscale=False format="JPEG" as image_768 %}
{% thumbnail self.image.file "1024" upscale=False format="JPEG" as image_1024 %}
<div class="parallax {% get_styling_classes self.styling %}" data-parallax="scroll" data-img="{{image.url}}" data-img-768="{{image_768.url}}" data-img-1024="{{image_1024.url}}" style="height: {{ self.height }};" >
    {% if not self.body|striptags == "null" %}
    <span class="overlay"></span>
    <div class="parallax-lead-wrapper" {% get_styling self.styling %}>
        <div class="parallax-lead">
            {{ self.body|convert_to_html }}
        </div>
    </div>
    {% endif %}
</div>
{% endthumbnail %}
{% endthumbnail %}
{% endthumbnail %}