from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "product_shadow")

variables = {
    "product-shadow": "true",
    "product-padding": "1",
    "product-rating": "false",
}
