{% load i18n %}

{% if form.is_bound and not form.is_valid %}
<div class="alert alert-danger" aria-live="assertive">
    <strong>{% trans "Oops! We found some errors" %}</strong> - {% trans "please check the error messages below and try again" %}
</div>
{% endif %}

{% if form.non_field_errors %}
{% for error in form.non_field_errors %}
<div class="alert alert-danger" aria-live="polite">
    <i class="fa fa-exclamation"></i> {{ error }}
</div>
{% endfor %}
{% endif %}

{% for field in form %}
{% if not field.name == "quantity" %}
{% include 'oscar/partials/form_field.html' with field=field style=style %}
{% endif %}
{% endfor %}