import subprocess
import sys


def remove_ocyan():
    return subprocess.check_output(
        [
            sys.executable,
            "-m",
            "pip",
            "uninstall",
            "ocyan.themes",
            "ocyan.plugin.themes",
            "--no-color",
            "--yes",
        ],
        stderr=subprocess.STDOUT,
    )
