{% extends "oscar/customer/wishlists/wishlists_detail.html" %}

{% load image_tags %}
{% load i18n %}
{% load widget_tweaks product_tags %}

{% block header %}
{{block.super}}
<a href="{% url 'customer:wishlists-update' key=wishlist.key %}">{% trans 'Edit' %} {% trans 'Wishlist' %}</a>
{% endblock %}

{% block tabcontent %}
{% if form.total_form_count %}
<div class="row">
    {% for subform in form %}
        {% with line=subform.instance product=subform.instance.product %}
            {% if product %}
                <div class="col-lg-3">
                    {% include "oscar/customer/wishlists/wishlists_product.html" with product=product line=line %}
                </div>
            {% endif %}
        {% endwith %}
    {% endfor %}
</div>
{% else %}
{% trans "Your wish list is empty." %}
{% endif %}

{% endblock tabcontent %}