.promo_header{
	padding: .5rem 0;
    background: $promo-background;
	.promo_header_inner{
		display: flex;
		justify-content: space-between;
		margin: 0 -.5rem;
		.promo_block{
			padding: 0 .5rem;
			*{
				color: color-contrast($promo-background) !important;
			}
			a[href]{
				color: initial;
				text-decoration: unset;
			}
			.rich-text{
				& > *:last-child{
					margin-bottom: 0;
				}
			}
		}
		.textslider{
			width: 100%;
			ul.textslider-stage{
				padding: 0;
				margin: 0 -.5rem !important;
				display: flex;
				li.textslide{
					list-style: none;
					padding: 0 .5rem;
				}
			}
		}
	}
}