@if $header-type == "mega"{
    .icon-dropdown{
        @extend .container;
        @include media-breakpoint-up(lg){
            margin-top: 0;
            left: 50%;
            transform: translateX(-50%);
            position: relative;
            padding: 1rem 0;
            &:before{
                content: "";
                position: absolute;
                top: 0;
                left: 0;
                width: 100%;
                height: 100%;
                background: $header-background;
                z-index: 1;
            }
            &:after{
                content: "";
                position: absolute;
                top: 0;
                left: 50%;
                width: 100vw;
                height: 100vh;
                transform: translateX(-50%);
                background: rgba(0,0,0,.5);
                z-index: -2;
                opacity: 1;
                transition: .2s ease;
                animation: fade-in 1s ease;
                pointer-events: none;
            }
            .icon_dropdown_devider{
            	display: block;
            	position: absolute;
            	top: 0;
            	left: calc(25% - 1rem);
                border-left: $border-width solid $gray-300;
            	width: 1px;
            	height: 100%;
            	z-index: 3;
            	pointer-events: none;
            }
            li.nav-item{
            	a.nav-link{
            		img{
                        width: 2rem;
                        height: 2rem;
                        object-fit: contain;
                        object-position: center;
                        margin-right: .25rem;
                        transition: .2s ease;
                    }
            	}
            }
            & > li.nav-item{
                position: unset;
                width: calc(25% - 2rem);
                & > a.nav-link{
                    padding: .5rem 1rem;
                    color: $gray-600;
                    position: relative;
                    display: flex;
                    align-items: center;
                    z-index: 2;
                    img{
                        opacity: .5;
                    }
                }
                & > ul.dropdown-menu.icon-inner-menu{
                    position: absolute;
                    top: 0;
                    left: 25%;
                    width: 75%;
                    padding: 1rem 0;
                    flex-wrap: wrap;
                    z-index: 1;
                    min-height: 100%;
                    & > li.nav-item{
                        width: 25%;
                        &.has-children{
                            & > a.nav-link{
                                font-weight: 700;
                                color: $gray-900;
                            }
                        }
                        a.nav-link, .dropdown-menu li.nav-item a.nav-link{
                            padding: .5rem 1rem;
                            color: $gray-700;
                            transition: .2s ease;
                            &:hover{
                            	background: $gray-100;
                            }
                        }
                        .dropdown-menu{
                            position: unset;
                            display: flex;
                            flex-direction: column;
                            padding: 0;
                        }
                    }
                    &:before{
                	    content: "";
    				    width: calc(100% * (1 / .75) * .25);
    				    position: absolute;
    				    top: 0;
    				    left: 0;
    				    transform: translateX(-100%);
    				    height: 100%;
    				    background: $header-background;
    				    z-index: -1;
    	            }
                }
                &.hover{
                    & > a.nav-link, & > a.nav-link.hover{
                        color: $gray-900;
                        font-weight: 600;
                        img{
                            opacity: 1;
                        }
                    }
                    & > ul.dropdown-menu{
                        display: flex;
                    }
                }
            }
        }
        @include media-breakpoint-down(lg){
        	display: block;
        	padding: 0;
        	.dropdown:not(:hover){
        		a.nav-link{
    	    		pointer-events: none;
        		}
        	}
        	.dropdown:hover{
        		.dropdown-menu{
        			display: flex;
        			flex-direction: column;
        		}
        	}
            & > li.nav-item{
                & > a.nav-link{
                    img{
                    	width: 3rem;
                    	height: 3rem;
                    	object-fit: contain;
                    	object-position: center;
                    }
                }
                ul.dropdown-menu{
                	padding: 0;
                	li.nav-item{
                		a.nav-link{
                			color: $gray-700;
                		}
                	}
                }
            }

        }
        &, .dropdown-menu{
            border: 0;
        }
        .all-products{
            i{
                font-size: 75%;
                margin-left: .5rem;
            }
            &.hover{
                i{
                    font-weight: 900;
                }
            }
        }
    }
}