{% extends "layout.html" %}
{% load i18n %}

{% block content %}
<section class="privacy-wrapper">
	<div class="container">
		<div class="row">
			<div class="col-xl-5 col-lg-7 col-md-8 mx-auto">
		        <div class="login-wrapper">
					<div class="login-header">{% trans "For this page you need to be logged in" %}</div>
					<form action="{{ action_url }}" method="POST">
					    {% csrf_token %}
				        {% for field in form %}
			        	<div class="icon_wrapper {{field.name}}">
		        			{% include "oscar/partials/form_field.html" with field=field placeholder=field.label nolabel=True %}
		        		</div>
				        {% endfor %}
				    	<div class="login-footer">
				    		<a href="{% url 'customer:login' %}" class="btn btn-outline-primary">
		                        {% trans 'Register' %}
		                    </a>
			        		<button type="submit" value="Continue" class="btn btn-primary">{% trans "Login" %}</button>
			        	</div>
					</form>
		        </div>
			</div>
		</div>
	</div>
</section>
{% endblock %}