@import "variables";
@import "vendor/bootstrap/bootstrap";
@import "partials/base";
@import "oscar/base";
@import "blocks/base";
@import "layout";

h1, h2, h3, h4, h5, .h1, .h2, .h3, .h4, .h5{
	font-family: $header-font-family;
	@media screen and (max-width: 991px){
		word-break: break-word;
	}
}

// Bootstrap 5 form-select overwrite for safari
.form-select{ -webkit-appearance:none; -moz-appearance:none; }

.link-unstyled, .link-unstyled:hover{
	text-decoration: unset;
	color: inherit;
}

.gd-primary{ background: linear-gradient(45deg, $primary, darken($primary, 20%)); }
.gd-dark{ background: linear-gradient(45deg, $gray-900, lighten($gray-900, 20%)); }
.gd-secondary{ background: linear-gradient(45deg, $secondary, darken($secondary, 10%)); }

@import "wcag";