{% extends "layout.html" %}
{% load static %}

{% block content_wrapper %}
<div class="container page" id="main_content" tabindex="-1">
    <div class="page_inner">
        {% block breadcrumbs %}{% endblock %}
        {% block subnavigation %}{% endblock %}
        <div class="content">
            {% block subheader %}{% endblock subheader %}

            {# Div exists for AJAX updates to entire content section #}
            <div id="content_inner">{% block content %}{% endblock %}</div>
        </div>
    </div>
</div>
{% endblock %}

{% block scripts %}
{{ block.super }}
<!-- Twitter Bootstrap -->
<!-- Oscar -->
<script src="{% static "oscar/js/oscar/ui.js" %}"></script>
{% endblock %}

{% block onbodyload %}
{{ block.super }}
oscar.init();
{% endblock %}
