.blogitem{
	a{
		box-shadow: unset !important;
		transform: unset !important;
		text-decoration: unset;
		&:hover{
			.img-wrapper span{
				opacity: 1;
				transform: rotate(35deg) translateX(15px) translateY(15px);
			}
		}
		.img-wrapper{
			position: relative;
			z-index: 3;
			span{
				position: absolute;
				top: 0;
				right: 0;
				z-index: -1;
				padding: 0rem;
				font-weight: 600;
				display: inline-flex;
				align-items: center;
				opacity: 0;
				transition: .35s ease;
				transform: rotate(35deg) translateX(15px) translateY(45px);
				i{
					width: 18px;
					height: 18px;
					font-size: .7rem;
					border-radius: 100%;
					display: inline-flex;
					flex-direction: column;
					justify-content: center;
					align-items: center;
					color: white;
					background: var(--bs-primary);
				}
			}
			img{
				height: 225px;
				object-fit: cover;
				transition: .35s ease;
			}
		}
		.blog-info{
			padding: 1rem 0 !important;
			border: 0 !important;
		}
	}
	.blog-outer{
		.blog-section{
			& > div{
				margin-bottom: 2rem;
			}
		}
	}

	.side_blog, .blog_item{
		img{
			width: 100%;
			height: 200px;
			object-fit: cover;
		}
		.image-wrapper{
			width: 100%;
			height: 200px;
			overflow: hidden;
			border-radius: $border-radius;
			img{
				width: 100%;
				height: 100%;
				object-fit: cover;
				transition: 1s cubic-bezier(.28,1.01,.27,1);
			}
		}
		&:hover{
			img{
				transform: scale(1.2);
				transition: 3s cubic-bezier(.28,1.01,.27,1);
			}
		}
	}

	.block-heading{
		h1{
			font-size: 2rem;
		}
	}

	.icon-wrapper{
	    width: 23px;
	    height: 23px;
	    font-size: .75rem;
		border-radius: 100%;
		background: var(--bs-primary);
		color: white;
		display: inline-flex;
		flex-direction: column;
		justify-content: center;
		align-items: center;
		font-weight: 600;
	}

	.blog-header-image{
		width: 100%;
		max-height: 30rem;
		object-fit: contain;
		object-position: left top;
	}

	.blog_filters{
		a{
			padding: .5rem 1rem;
			background: var(--bs-primary);
			color: white !important;
			border-radius: 2rem;
			border: 2px solid var(--bs-primary);
			font-weight: 600;
			user-select: none;
			cursor: pointer;
			transition: .2s ease;
			display: inline-block;
			margin-bottom: .5rem;
			&:not(.active), &:not(:hover){
				color: var(--bs-primary) !important;
				background: transparent;
			}
			&:hover{
				color: white !important;
				background: var(--bs-primary);
			}
		}
	}
}


.blog-cta{
    position: absolute;
    bottom: 0px;
    right: 1rem;
    height: calc(100% + 5rem);
    width: 33.3333%;
    object-fit: contain;
}