.product-rating{
    @if $product-rating == "true"{
        display: flex;
    }@else{
        display: none;
    }
    align-items: center;
    font-size: $font-size-sm;
    flex-wrap: wrap;
    @extend .mb-2;
    .product-rating-count{
        @extend .ms-2;
    }
}

.star-wrapper {
    white-space: nowrap;
    &.star-rating{
        &.One  { i:nth-child(-n+1){ color:#ffcd00; } }
        &.Two  { i:nth-child(-n+2){ color:#ffcd00; } }
        &.Three{ i:nth-child(-n+3){ color:#ffcd00; } }
        &.Four { i:nth-child(-n+4){ color:#ffcd00; } }
        &.Five { i:nth-child(-n+5){ color:#ffcd00; } }
        i{
            cursor: pointer;
        }
    }
    .fa-star-solid{
        color: #e6e6e6;
        &.active{
            color: #ffcd00;
        }
        &.half{
            position: relative;
            &:after{
                content: "\f051";
                position: absolute;
                top: 0;
                left: 0;
                color: #ffcd00;
            }
        }
    }
}

.add_review_form{
    @extend .mb-5;
    .reviewrating{
        .controls{
            select{
                display: none;
            }
            .star-wrapper{
                i{
                    font-size: 2rem;
                }
            }
        }
    }
    .review-header{
        @extend .mb-3;
        text-transform: capitalize;
    }
    .review_form{
        .review-bottom{
            @extend .mb-3;
        }
        .form-group{
            @extend .mb-3;
            .product-rating{
                @extend .mb-0;
            }
            label{
                font-weight: 500;
                font-size: 1.25rem;
            }
        }
    }
    @include media-breakpoint-up(md){
        .product .product-image:before{
            padding-top: 85%;
        }
    }
}

.review-wrapper{
    @extend .mb-5, .mt-4;
    list-style: none;
    padding-left: 0;
    .sub-header{
        display: flex;
        justify-content: space-between;
        align-items: center;
    }
    .review-item{
        &:not(:last-child){
            @extend .mb-3;
            @extend .pb-3;
            border-bottom: 1px solid $gray-300;
        }
    }
    .review-header{
        .product-rating{
            width: 100%;
            justify-content: space-between;
            .star-outer-wrapper{
                justify-content: space-between;
                display: flex;
                align-items: center;
                h2{
                    @extend .me-3;
                    font-weight: 600;
                    @include media-breakpoint-up(md){
                        font-size: 3rem;
                    }
                }
                i{
                    font-size: 2rem;
                }
            }
        }
        .no-reviews{
            width: 100%;
            display: flex;
            align-items: center;
            justify-content: space-between;
            @extend .py-3;
        }
    }
}

.review{
    .star-content{
        display: flex;
        @extend .mb-3;
        .review-title{
            @extend .ms-2;
            @extend .mb-0;
            @extend .text-dark;
            text-decoration: unset;
            font-weight: 600;
        }
    }
    .review-user{
        @extend .text-muted;
    }
    .inline-buttons{
        display: flex;
        align-items: center;
        form{
            @extend .me-2;
            button{
                i{
                    @extend .me-1;
                }
            }
        }
    }
}

.review-list{
    @extend .my-5;
}