{% extends "oscar/catalogue/partials/product.html" %}

{% load ocyan_thumbnail ocyanjson %}

{% block product_image %}
{% ocyanjson "themes" "thumbnail_geometry" "305x305" as thumbnail_geometry %}
{% with image=product.primary_image %}
<a class="product-image" href="{{ product.get_absolute_url }}" aria-label="Product image">
{% picture image.original thumbnail_geometry upscale=False alt=image.caption|default:product.title %}
</a>
{% endwith %}
{% endblock %}
