{% extends "oscar/checkout/layout.html" %}
{% load i18n %}
{% load category_tags %}

{% block layout %}
<div class="container checkout {% block wrapper_class %}{% endblock %} position-relative">
    {% block wrapper_header %}
    {% endblock %}
   <div class="page_inner">
    <!-- The main nav on checkout pages contain links to modal flatpages -->
    {% block modal %}
    {% load flatpages %}
    {% get_flatpages '/order/' as flatpages %}
    {% for page in flatpages %}
    <div id="{{ page.title|slugify }}" class="modal hide fade">
        <div class="modal-header">
            <button class="close" data-dismiss="modal">×</button>
            <h3>{{ page.title }}</h3>
        </div>
        <div class="modal-body">
            <div class="large-content">
                {{ page.content|safe }}
            </div>
        </div>
    </div>
    {% endfor %}
    {% endblock %}
    {% block content %}{% endblock %}
    </div><!-- /page_inner -->
    {% block tracking %}
    {% endblock %}
    {% block footer %}
    {% endblock %}
</div>
{% endblock %}
