{% load i18n ocyan_thumbnail %}
{% if menu_items %}
{% for menu_item in menu_items %}
{% with category_icon=menu_item.category.icons.first %}        
<li class="nav-item head">
    <a class="nav-link" href="{{ menu_item.get_absolute_url }}">
        {{ menu_item.name }}
    </a>
</li>
{% endwith %}
{% endfor %}
{% endif %}