<div class="product-carousel">
    {% for product_slide in self %}
	<div class="product-carousel-item">
        {% if product_slide.product is not None %}
        {% include "roadrunner_bs4/partials/product.html" with product=product_slide.product %}
        {% endif %}
	</div>
    {% endfor %}
</div>
