{% block top %}{% endblock %}
{% if form.visible_fields|length > 0 or nohide %}
<div class="panel panel-default"{% if id %} id="{{ id }}"{% endif %}>
	{% block panel_header %}
    <div class="panel-heading">
        <h3 class="panel-title">{{ title }}</h3>
    </div>
    {% endblock %}
    
    <div class="panel-body">
      {% block panel_body %}
      {% for field in form.hidden_fields %}
        {{ field }}
      {% endfor %}

      {% for field in form.visible_fields %}
        {% include "oscar/partials/form_field.html" with field=field nolabel=nolabel|default_if_none:False %}
      {% endfor %}
      {% endblock %}
      {% block panel_footer %}{% endblock %}
    </div>
</div>
{% else %}
{% for field in form.hidden_fields %}
  {{ field }}
{% endfor %}
{% endif %}
{% block bottom %}{% endblock %}