# Generated by Django 2.2.13 on 2021-01-28 09:48

from django.db import migrations

from ocyan.core.fender import config
# pylint: disable=no-member
if "ocyan.plugin.wagtail" in config.ocyan_plugins:

    class Migration(migrations.Migration):

        initial = True

        dependencies = [
            ('wagtailcore', '0001_initial'),
        ]

        operations = [
            migrations.CreateModel(
                name='PageMenuProxy',
                fields=[
                ],
                options={
                    'verbose_name': 'Empty page',
                    'verbose_name_plural': 'Empty pages',
                    'abstract': False,
                    'managed': False,
                    'proxy': True,
                },
                bases=('wagtailcore.page',),
            ),
        ]
else:
    class Migration(migrations.Migration):
        initial = True
        options = []
