{% extends "oscar/layout.html" %}

{% comment %}
Keep the same header and footer as the standard layout template but override the
main content area to split it into a sidebar and a content block
{% endcomment %}
{% block content_wrapper %}
<div class="{% block content_wrapper_classes %}container page{% endblock %}" id="main_content" tabindex="-1">
    <div class="page_inner">
        {% block breadcrumbs %}{% endblock %}
        <div class="row">
            <aside class="sidebar col-md-4 col-lg-3">
                {% block column_left %}{% endblock %}
                {% block column_left_extra %}{% endblock %}
            </aside>
            <div class="col-md-8 col-lg-9">
                {% block header %}
                <div class="page-header">
                    <h1>{% block headertext %}{% endblock %}</h1>
                </div>
                {% endblock %}

                {% block pre_content %}{% endblock %}
                {% block content %}{% endblock %}
            </div>
        </div><!-- /row -->
    </div><!-- /page_inner -->
</div><!-- /container -->
{% endblock %}