.thankyou_header{
    @extend .my-3;
    display: block;
    margin-left: auto;
    margin-right: auto;
    text-align: center;
}

.thankyoupage{
    background: $gray-100;
    .brand-thankyou{
        @extend .d-block, .mx-auto, .text-center, .mb-3;
    }
    .lead{
        @extend .mb-3;
    }
    .thankyou_line{
        @extend .mb-3;
    }
    .thankyou_row{
        @extend .my-3;
    }
    .thankyou_wrapper{
        max-width: 45rem;
        background-color: $white;
        box-shadow: 0 0 1rem rgba(0,0,0,.1);
        margin: 4em auto;
        padding: 1em 2em;
        animation: floatIn 1s ease;
    }
    .receipt_footer{
        position: absolute;
        width: 100%;
        bottom: .1rem;
        left: 0;
        transform: translateY(100%);
        fill: $white;
    }
    .receipt_headersvg{
        position: absolute;
        width: 100%;
        top: .1rem;
        left: 0;
        transform: translateY(-100%);
        fill: $white;
        z-index: 99;
    }
    .receipt_header{
        border-bottom: 2px solid #cfcfcf;
        font-size: 1.2em;
        font-weight: bold;
    }
    .order_actions{
        display: flex;
        justify-content: flex-end;
        a{
            @extend .ms-2;
        }
    }
    .thankyou-table{
        .basket-items{
            border: none !important;
            padding: 0 !important;
        }
        th, td{
            padding: 0 !important;
        }
    }

    .info-block img {
        width: 100%;
        height: auto;
    }

    .total p{
        margin: 0;
    }

    .flex-end{
        align-items: flex-end;
    }

    .recent-wrapper article.product_pod{
        display: flex;
        flex-direction: column;
        height: 100%;
        justify-content: space-between;
    }

    .big-head-menu{
        margin-right: unset !important;
    }

    .nav-extra li a{
        padding: 1rem .5em !important;
    }


    .nav_extra .nav-link{
        padding: 1em .5em !important;
    }

    .dropdown-divider{
        margin: 0;
        border-color: $white;
    }

    #gateway > div.card-body > #passwords {
        max-height: 0;
        overflow: hidden;
        -webkit-transition: max-height .2s; /* For Safari 3.1 to 6.0 */
        transition: max-height .2s;
        margin-top:0;
    }

    #loginbutton {
        display: none;
    }

    #search_promotions{
        padding: 0;
        list-style: none;
        a{
            text-decoration: none !important;
            padding: .75rem 0;
            transition: .2s ease;
            display: block;
            border-bottom: 0;
            .small-lead{
                color: #666;
                display: block;
            }
        }
        li{
            border-bottom: 1px solid #ddd;
            .search_badge{
                border: 1px solid black;
                padding: 0px .25rem;
                display: inline-block;
                border-radius:5px;
                margin: .25rem 0;
            }
        }
    }
    .receipt_body{
        @extend .my-4;
    }
}



