{% load django_tables2 %}
{% load i18n %}
<div class="btn-toolbar dropdown">
    <button class="btn btn-primary dropdown-toggle" type="button" data-toggle="dropdown" aria-expanded="true">
        {% trans "Actions" %}
        <span class="caret"></span>
    </button>
    <ul class="dropdown-menu">
        <li>
            <a class="dropdown-item" href="{% url 'dashboard:catalogue-product' pk=record.id %}{% querystring %}">{% trans "Edit" %}</a>
        </li>
        {% block extra_product_row_actions %}{% endblock %}
        <li>
            <a class="dropdown-item" href="{{ record.get_absolute_url }}"> {% trans "View on site" %}</a>
        </li>
        <li>
            <a class="dropdown-item" href="{% url 'dashboard:catalogue-product-delete' pk=record.id %}">{% trans "Delete" %}</a>
        </li>
    </ul>
</div>
