{% load i18n %}
<button class="navbar-toggler" aria-label="Navbar toggle" type="button" data-bs-toggle="collapse" data-bs-target=".menu-bar">
    <i class="fa fa-bars nav-icon"></i>
</button>
<div class="search-wrapper">
    <a data-bs-toggle="dropdown" class="nav-link"><i class="fa fa-search nav-icon"></i></a>
    <div class="dropdown-menu">
        <h4>{% trans "Search" %}</h4>
        {% include 'oxyan/headers/partials/search.html' %}
    </div>
</div>
<div class="user-wrapper">
    {% include 'oxyan/headers/partials/user.html' %}
</div>
<div class="mini-basket-wrapper">
    {% include 'oxyan/headers/partials/mini_basket.html' %}
</div>
<div class="container">
    <div class="alert-messages-header" aria-live="polite">
        {% include "oscar/partials/alert_messages.html" with messages=messages %}
    </div>
</div>