.search-header-wrapper{
    position: relative;
    background: linear-gradient(45deg, var(--bs-dark), var(--bs-primary));
    padding: 0;
    min-height: 300px;
    @media screen and (min-width: 991px) {
        border-radius: 1rem;
    }
    .search-page-inner{
        position: absolute;
        top: 45%;
        transform: translateY(-50%);
        display: flex;
        justify-content: center;
        flex-direction: column;
        align-items: center;
        text-align: center;
        width: 100%;
        padding: 1rem 5rem;
        .search-hero-banner{
            color: white;
        }
    }
    .search-form-wrapper{
        position: relative;
        border-radius: 24px;
        overflow: hidden;
        .btn{
            position: absolute;
            top: 50%;
            right: 0;
            transform: translateY(-50%);
        }
    }
}

.search-result-block{
    padding: 2rem;
    border-radius: 1rem;
    overflow: hidden;
    text-decoration: none;
    display: flex;
    flex-direction: column;
    .search-result-description{
        color: black;
    }
}