.footer .row .footer_column {
   @extend .py-5;
}

.footer{
   background-color: $footer-bg;
   .footer_column * {
      color: color-contrast($footer-bg);
   }
   .footer_header{
      font-size: 1.2rem;
      font-weight: 600;
      display: inline-block;
      margin-bottom: .5rem;
   }
}

.copyright_wrapper {
   background-color: shift_color($footer-bg, 10%);
   @extend .py-3;
   .copyright_block *{
      margin: 0;
      color: color-contrast($footer-bg);
   }
}