{% extends 'layout.html' %}
{% load ocyan_main %}

{% block description %}{% if page.meta_description %}{{ page.meta_description }}{% else %}{{ block.super }}{% endif %}{% endblock %}
{% block title %}{% if page.get_meta_title %}{{ page.get_meta_title }}{% else %}{{ block.super }}{% endif %}{% endblock %}

{% block extrahead %}
<link rel="canonical" href="{% if page.canonical_url %}{{ page.canonical_url }}{% else %}{% absolute_url request.path %}{% endif %}">
{% if page.meta_keywords %}<meta name="keywords" content="{{ page.meta_keywords }}">{% endif %}
{{ block.super }}
{% endblock %}