from django.urls import path

from .views import preview_theme_css

app_name = "themes"

urlpatterns = [
    path(
        "css/preview-<slug:theme_name>.css",
        view=preview_theme_css,
        name="preview-theme",
    ),
]
