.basket, .saved-basket{
    @extend .my-5;
    .basket-header{
        @extend .mb-5;
    }
    .basket-summary, .saved-basket-items{
        .basket-items{
            &:not(:last-of-type){
                border-bottom: 1px solid $border-color;
                @extend .mb-4, .pb-4;
            }

            p{
                margin: 0;
            }
            .basket-line-actions{
                @extend .mt-lg-3;
            }
            .basket-line-total{
                @extend .mt-4, .mt-lg-3;
                .stock_price{
                    display: flex;
                    flex-wrap: wrap;
                    align-items: center;
                    justify-content: flex-end;
                    .from_price{
                        order: 1;
                        width: 100%;
                    }
                    .first-session-price{
                        order: 3;
                    }
                    .second-session-price{
                        order: 2;
                    }
                }
            }
            .basker-line-description{
                @extend .mb-3, .mb-lg-0;
            }
            .basket-line-actions{
                .basket-line-action-text, .basket-line-actions-devider{
                    @extend .d-none, .d-lg-inline-block;
                }
                i{
                    @extend .d-lg-none;
                    @extend .me-3;
                    @include media-breakpoint-down(lg){
                        font-size: 1.3rem;   
                    }
                }
            }
            @include media-breakpoint-down(lg){
                .basket-info .row{ align-items: center; }
                .basker-line-quantity{ order: 3; }
                .basket-line-actions{ order: 2; }
                .basket-line-total{ order: 4; }
            }
            .basket-line-description{
                @extend .mb-3, .mb-lg-0;
            }

            .basket-info{
                display: flex;
                flex-direction: column;
                justify-content: space-between;
                .basket-line-description{
                    p, .line-description{
                        @extend .text-muted;
                        @extend .small;
                    }
                    .line-description, .line-attributes{
                        @extend .mt-3;
                        .product-attr{
                            @extend .text-muted;
                            @extend .small;
                        }
                    }
                }
            }
        }
        .price-quantity{
            text-align: right;
            display: flex;
            align-items: center;
            justify-content: flex-end;
            .basket-item-price{
                text-align: right;
                @extend .me-3;
            }
            .basket-item-quantity{
                input{
                    min-width: 4.5rem;
                }
                .rotate-1{
                    animation: rotate1 .4s ease-out;
                }
            }
        }
        .basket-item-total{
            text-align: right;
            .price_color{
                font-weight: 600;
            }
        }
    }
    .basket-right{
        @extend .ps-lg-5;
        .sticky-basket{
            position: sticky;
            top: 2rem;
        }
        .basket-voucher-wrapper{
            @extend .mb-3;
            .basket-voucher{
                @extend .mt-3;
            }
        }
        .basket-totals-wrapper{
            @include basket-totals-wrapper;
            table.totals-table{
                table-layout: fixed;
                tr{
                    td:first-child{
                        width: 60%;
                    }
                    th.total{
                        padding-top: 0;
                    }
                    td, th{
                        &:last-child{
                            text-align: left;
                        }
                    }
                }
                .shipping_alert{
                    font-size: .8rem;
                    display: block;
                    opacity: .6;
                }
                .removevoucher{
                    display: inline;
                    padding-right: .25rem;
                    label{
                        cursor: pointer;
                    }
                    input{
                        display: none;
                    }
                }
                &.tax-table{
                    display: none;;
                }
            }
        }
    }
}

.saved-basket{
    @include basket-totals-wrapper;
    @extend .mb-0;
    .sub-header{
        @extend .mb-5;
    }
}

.emptybasket{
    margin: 5rem 0;
    padding: 0 1rem;
    text-align: center;
    h2{
        @include media-breakpoint-up(lg){
            font-size: 4rem;
        }
    }
    a{
        @extend .mt-5;
    }
}

@keyframes rotate1{
    from { transform: rotate(0deg); }
    to { transform: rotate(360deg); }
}

#id_code{
    @extend .bg-light;
    border-width: 2px;
    border-top-right-radius:0;
    border-bottom-right-radius:0;
    border-top-left-radius:.25rem;
    border-bottom-left-radius:.25rem;
    border-color: $primary;
    &::placeholder{
        opacity: .6;
    }
}