{% load static %}
{% load wagtailcore_tags wagtailimages_tags wagtailsettings_tags cache %}
{% get_settings %}

{% cache 300 footer_menu LANGUAGE_CODE request.site %}
<footer class="footer">
    <div class="container">
        <div class="row">
            {% with footer=settings.ocyan_plugin_wagtail.OcyanSettings.footer %}
            {% for block in footer %}
            <div class="col-lg-3 col-md-6 col-sm-12 footer_column {{ block.block_type|slugify }}">
                {% include_block block %}
            </div>
            {% endfor %}
            {% endwith %}
        </div>
    </div>
</footer>

<section class="copyright_wrapper">
    <div class="container">
        <div class="row">
            <div class="col-lg-12 copyright_block">
                {% include_block settings.ocyan_plugin_wagtail.OcyanSettings.mini_footer %}
            </div>
        </div>
    </div>
</section>
{% endcache %}
