from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "dark")

variables = {
    "white": "#1f2326",
    "gray-100": "#36393c",
    "gray-200": "#4b4f51",
    "gray-300": "#616466",
    "gray-400": "#787c7d",
    "gray-500": "#adb5bd",
    "gray-600": "#a6a7a8",
    "gray-700": "#bcbdbd",
    "gray-800": "#d3d3d4",
    "gray-900": "#e8e9e9",
    "body-background": "#1f2326",
    "body-color": "#fff",
    "header-background": "#25282b",
    "header-link-color": "#fff",
    "search-background": "#1f2326",
    "footer-background": "#25282b",
    "footer-color": "#fff",
    "promo-background": "#2f3236",
    "promo-color": "#fff",
    "price-color": "#fff",
    "light": "#36393c",
    "black": "#fff",
}
