.parallax{
	position: relative;
	.overlay{
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		background: rgba(0,0,0,.5);
		z-index: 1;
	}
	.parallax-image-wrapper{
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		z-index: 0;
		overflow: hidden;
		.parallax-image{
			position: absolute;
			top: -50%;
			left: 0;
			width: 100%;
			height: 200%;
			img{
				width: 100%;
				height: 100%;
				object-fit: cover;
				object-position: center;
			}
		}
	}
	.parallax-lead-wrapper{
		@extend .container;
		padding-left: calc(var(--bs-gutter-x) * .5);
		padding-right: calc(var(--bs-gutter-x) * .5);
		position: relative;
		z-index: 2;
		.parallax-lead{
			padding: 4rem 0;
			&.text-white{
				*{
					color: white;
				}
			}
        	@include media-breakpoint-up(lg){
        		max-width: 65%;
        	}
		}
	}
}

.text-center{
	.parallax{
		.parallax-lead{
			margin-left: auto;
			margin-right: auto;
        	@include media-breakpoint-up(lg){
        		max-width: 50%;
        	}
		}
	}
}