from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "product_borders")

variables = {
    "border-radius": ".3",
    "product-border-width": "1",
    "product-padding": "1",
}
