{% extends "oscar/customer/profile/profile.html" %}

{% load i18n static %}

{% block tabcontent %}
<div class="row">
    <div class="col-lg-6">
        <div class="tabcontent-item tabcontent-even">
            <div class="tabcontent-item-body">
                <h5>{% trans "Personal information" %}</h5>
                <table class="table table-profile">
                    <tbody>
                        <tr>
                            <td>{% trans 'Name' %}:</td>
                            <td>{{ user.get_full_name|default:'-' }}</td>
                        </tr>
                        <tr>
                            <td>{% trans 'Date registered' %}:</td>
                            <td>{{ user.date_joined }}</td>
                        </tr>
                        <tr>
                            <td>{% trans 'Email address' %}:</td>
                            <td>{{ user.email }}</td>
                        </tr>
                        {% block profile_fields %}
                        {% for field in profile_fields %}
                        <tr>
                            <td>{{ field.name }}</td>
                            <td>{{ field.value|default:"-" }}</td>
                        </tr>
                        {% endfor %}
                        {% endblock %}
                    </tbody>
                </table>
            </div>
            {% block profile_edit %}
                <div class="tabcontent-item-footer">
                    <a href="{% url 'customer:profile-update' %}" class="btn btn-primary icon-left"><i class="fa fa-cog-solid small"></i> {% trans 'Edit profile' %}</a>
                </div>
            {% endblock profile_edit %}
        </div>
    </div>

    <div class="col-lg-6">
        <div class="tabcontent-item tabcontent-even">
            <div class="tabcontent-item-body">
                <h5>{% trans "Login information" %}</h5>
                <table class="table table-borderless table-sm table-no-padding">
                    <tbody>
                        <tr>
                            <td>{% trans 'Email address' %}:</td>
                            <td>{{ user.email }}</td>
                        </tr>
                        <tr>
                            <td>{% trans 'Password' %}:</td>
                            <td>*******</td>
                        </tr>
                    </tbody>
                </table>
            </div>
            <div class="tabcontent-item-footer">
                <a href="{% url 'customer:change-password' %}" class="btn btn-primary icon-left"><i class="fa fa-cog-solid small"></i> {% trans 'Change password' %}</a>
            </div>
        </div>
    </div>
    {% block extra_profile_rows %}{{ block.super }}{% endblock %}
</div>
{% endblock %}