{% extends "oscar/customer/baseaccountpage.html" %}

{% load i18n %}

{% block title %}{{ page_title }} | {% trans 'Account' %} | {{ block.super }}{% endblock %}

{% block body_class %}account-profile{% endblock %}

{% block header_breadcrumbs %}{% endblock %}

{% block header_title %}{% endblock %}

{% block content_wrapper %}
<div class="{% block content_wrapper_classes %}container page{% endblock %}">
    <div class="page_inner accountpage-wrapper">
        <div class="row">
            <aside class="sidebar col-md-4 col-lg-3">
            {% block column_left %}
            <ul class="nav navbar-nav navbar-tabs account-tabs">
                {% block standard_tabs %}
                    {% include 'oscar/customer/partials/standard_tabs.html' %}
                    {% block extra_tabs %}
                        {{block.super}}
                    {% endblock %}
                {% endblock %}
            </ul>
            {% endblock %}
            </aside>

            <div class="col-md-8 col-lg-9">
                {% block header %}
                {{block.super}}
                {% endblock %}

                {% block pre_content %}{% endblock %}
                {% block content %}
                <div class="tabcontent">{% block tabcontent %}{% endblock tabcontent %}</div>
                {% endblock content %}
            </div>
        </div>
    </div>
</div>
{% endblock content_wrapper %}
