{% extends "roadrunner/roadrunner_page.html" %}
{% load static ocyan_main wagtailcore_tags %}

{% block description %}{% if page.meta_description %}{{ page.meta_description }}{% else %}{{ block.super }}{% endif %}{% endblock %}
{% block title %}{% if page.get_meta_title %}{{ page.get_meta_title }}{% else %}{{ block.super }}{% endif %}{% if page.get_site.site_name %} - {{ page.get_site.site_name }}{% endif %}{% endblock %}

{% block extrahead %}
<link rel="canonical" href="{% if page.canonical_url %}{{ page.canonical_url }}{% else %}{% absolute_url request.path %}{% endif %}">
{% if page.noindex %}<meta name="robots" content="noindex">{% endif %}
{% if page.meta_keywords %}<meta name="keywords" content="{{ page.meta_keywords }}">{% endif %}
{{ block.super }}
{% endblock %}

{% block roadunnercss %}{% comment %}
The css is in oxyan
{% endcomment %}
{{ block.super }}  
{% endblock %}

{% block roadrunnerscripts %}{% comment %}
The scripts are in oxyan
{% endcomment %}
{{ block.super }} 
{% endblock %}

{% block highlight_slider %}{% endblock %}

{% block content_wrapper %}
<div class="content_wrapper" id="main_content" tabindex="-1">
    {% block content %}
    {% for block in page.content %}
        {% include_block block with block_key=block.id %}
    {% endfor %}
    {% endblock %}
</div>
{% endblock %}

{% block onbodyload %}
{{block.super}}
oxyan.initDataSliders()
oxyan.productSlider()
oxyan.productCarousel()
oxyan.IconSlider()
oxyan.oxyanSlider()
oxyan.highlightSlider()
oxyan.initHighlightedSlider()
oxyan.initParallax()
{% endblock %}
