{% extends "errors.html" %}
{% load i18n %}

{% block title %}403 - CSRF Token failed{% endblock %}

{% block error_header %}403{% endblock %}
{% block error_sub_header %}{% trans reason %}{% endblock %}
{% block error_body %}
{% if no_referer %}
    <p>{{ no_referer1 }}</p>
    <p>{{ no_referer2 }}</p>
    <p>{{ no_referer3 }}</p>
{% endif %}
{% if no_cookie %}
    <p>{{ no_cookie1 }}</p>
    <p>{{ no_cookie2 }}</p>
{% endif %}
<div class="button-wrapper">
    <a class="btn btn-outline-dark" onclick="location.reload();">{% trans 'Reload the page' %}</a>
    <a class="btn btn-dark" href="/">{% trans "Go to homepage" %}</a>
</div>
{% endblock %}