{% load ocyan_thumbnail %}

<div class="row mb-5">
    {% for child in category.get_public_children %}
        <div class="col-md-6 col-lg-4 col-12 mt-3 category-block">
            <a href="{{child.get_absolute_url}}">
                <div class="card h-100 text-center">
                    <div class="card-body d-flex flex-column">
                        {% lazy_picture child.image "x150" upscale=False alt=child.name %}
                    </div>
                    <span class="h6 mt-auto text-dark"><strong>{{child.name}}</strong></span>
                </div>
            </a>
        </div>
    {% endfor %}
</div>
