{% load i18n thumbnail ocyan_thumbnail %}

{% if av.value is True %}
{% trans "Yes" %}
{% elif av.value is False %}
{% trans "No" %}
{% elif av.attribute.type == "file" and av.value %}
<a href="{{ av.value_as_html.url }}" target="_blank" style="word-break: break-all;" title="{% trans 'Open file' %}">{{ av.file_as_text }}</a>
{% elif av.attribute.type == "image" and av.value %}
<a href="{{ av.value_as_html.url }}" target="_blank" style="word-break: break-all;" title="{% trans 'Open in original size' %}">
    {% lazy_picture av.value "200x200" upscale=False alt=av.attribute.name %}
</a>
{% else %}
{{ av.value_as_html }}
{% endif %}