body:not(.no-layout){
	.content_wrapper{
		section{
			&:not([class]){
				margin-top: $grid-gutter-height;
				margin-bottom: $grid-gutter-height;
				&:nth-child(1){
					margin-top: 0;
				}
			}
			&[style*="background"]{
				padding-top: $grid-gutter-height;
				padding-bottom: $grid-gutter-height;
				margin-top: 0;
				margin-bottom: 0;
			}
			& > .container, & > .container-fluid{
				&.container-fluid{
					padding-left: 0;
					padding-right: 0;
					& > .row{
						margin-left: 0;
						margin-right: 0;
					}
				}
			}
			& > .container-fluid{
				& > .row{
					& > div{
						padding-left: 0;
						padding-right: 0;
					}
				}
			}
		}
	}
}