.stock_price{
    @extend .mb-2;
    &:not(.swap){
        .second-session-price{
            @include media-breakpoint-up(md){
                &:before{
                    content: "/";
                    margin-left: 5px;
                }
            }
        }
    }
    &.swap{
        .second-session-price{
            @include media-breakpoint-up(md){
                &:after{
                    content: "/";
                    margin-right: 5px;
                }
            }
        }
    }
    .price_color{
        color: $price-color;
    }
    .first-session-price{
        font-size: $font-size-lg;
        font-weight: 700;
    }
    .second-session-price{
        color: $gray-500;
        font-size: .75rem;
        @include media-breakpoint-down(md){
            display: block;
        }
    }
    .from_price{
        text-decoration: line-through;
        display: block;
        color: $gray-500;
        font-weight: 400;
    }
}

.basket-lines{
    .product-specification{
        .stock_price{
            flex-wrap: wrap;
            .from_price{
                display: block;
                width: 100%;
                text-decoration: line-through;
                color: $gray-500 !important;
                font-weight: 500;
                margin-left: 0 !important;
            }
        }
    }
}
