{% load display_tags i18n %}


<li class="page-item{% if is_current_page %} active{% else %} d-none d-lg-block{% endif %}{% if ellipsis %} disabled{% endif %}">
    <a class="page-link" {% if not ellipsis %}href="?{% get_parameters 'page' %}page={{ page_number }}"{% endif %}>
        {{page_number}}
    </a>
</li>