{% extends "oscar/customer/address/address_delete.html" %}
{% load i18n %}

{% block tabcontent %}
<form method="post">
    {% csrf_token %}
    <p>{% trans 'Are you sure you want to delete this address?' %}</p>

    <div class="row">
        <div class="col-4">
            <p><strong>{{ object.summary }}</strong></p>
        </div>
    </div>

    <div class="form-group form-actions">
        <button type="submit" class="btn btn-danger" data-loading-text="{% trans 'Deleting...' %}">{% trans 'Delete' %}</button> {% trans 'or' %} <a href="{% url 'customer:address-list' %}">{% trans 'cancel' %}</a>
    </div>
</form>
{% endblock tabcontent %}
