{% load styling_tags %}

<div class="ratio ratio-4x3" {% get_styling self.styling %}>
    <iframe src="{{ self.url }}" allowfullscreen="allowfullscreen" mozallowfullscreen="mozallowfullscreen" msallowfullscreen="msallowfullscreen" oallowfullscreen="oallowfullscreen" webkitallowfullscreen="webkitallowfullscreen"></iframe>
</div>
