{% load wagtailcore_tags wagtailimages_tags i18n %}

{% with logo=settings.ocyan_plugin_wagtail.OcyanSettings.logo %}
<span class="logo">{% image logo width-200 class="img-responsive" %}</span>
{% endwith %}
{% include_block self.bound_blocks.content %}

{% with settings=settings.ocyan_plugin_wagtail.OcyanSettings %}
<div class="contact">
    {% if settings.phone_number %}
    <span class="icon-headphones"></span>{% trans "Bel ons:" %} <a href="tel:{{ settings.phone_number }}">{{ settings.phone_number }}</a> <br>{% endif %}
    {% if settings.email_address %}
    <span class="icon-envelope-alt"></span>{% trans "Mail ons:" %} <a href="mailto:{{ settings.email_address }}">{{ settings.email_address }}</a>
    {% endif %}
</div>
<div class="social">
    {% if settings.facebook_url %}
    <a aria-label="Facebook link" href="{{ settings.facebook_url }}" title="{% trans "Facebook navigation" %}"><i class="fa fa-facebook" aria-hidden="true"></i></a>
    {% endif %}
    {% if settings.twitter_url %}
    <a aria-label="Twitter link" href="{{ settings.twitter_url }}" title="{% trans "X navigation" %}"><i class="fa fa-twitter-x" aria-hidden="true"></i></a>
    {% endif %}
    {% if settings.linkedin_url %}
    <a aria-label="Linkedin link" href="{{ settings.linkedin_url }}" title="{% trans "Linkedin navigation" %}"><i class="fa fa-linkedin" aria-hidden="true"></i></a>
    {% endif %}
    {% if settings.instagram_url %}
    <a aria-label="Instagram link" href="{{ settings.instagram_url }}" title="{% trans "Instagram navigation" %}"><i class="fa fa-instagram" aria-hidden="true"></i></a>
    {% endif %}
    {% if settings.youtube_url %}
    <a aria-label="Youtube link" href="{{ settings.youtube_url }}" title="{% trans "Youtube navigation" %}"><i class="fa fa-youtube" aria-hidden="true"></i></a>
    {% endif %}
    {% if settings.pinterest_url %}
    <a aria-label="Pinterest link" href="{{ settings.pinterest_url }}" title="{% trans "Pinterest navigation" %}"><i class="fa fa-pinterest" aria-hidden="true"></i></a>
    {% endif %}
    {% if settings.tiktok_url %}
    <a aria-label="TikTok link" href="{{ settings.tiktok_url }}" title="{% trans "TikTok navigation" %}"><i class="fa fa-tiktok" aria-hidden="true"></i></a>
    {% endif %}
</div>
{% endwith %}
