{% extends "oxyan/headers/header.html" %}

{% load currency_filters i18n oxyan category_tags ocyan_main ocyanjson cache wagtailsettings_tags %}

{% block header %}
<header class="goods">
    <nav class="navbar navbar-expand-lg navbar-light header-inner">
        <div class="container">
            {% include 'oxyan/partials/brand.html' with big=True %}

            {% block nav %}
            {% ocyanjson "theme" "menu_depth" 1 as menu_depth %}
            {% category_tree depth=menu_depth as category_tree_items %}
            {% cache 300 header_page_menu LANGUAGE_CODE request.site %}
            <div class="collapse navbar-collapse menu-bar page-menu-bar">
                <ul class="navbar-nav">
					{% include "oxyan/partials/goods_dropdown.html" with menu_items=category_tree_items mega_menu=True dropdown=True %}
                    {% rootpage_as_category as page_tree_root %}
                    {% category_tree 2 page_tree_root as page_tree_items %}
                    {% include "oxyan/partials/dropdown.html" with menu_items=page_tree_items limit=2 %}
                </ul>
            </div>
            {% endcache %}
            {% endblock %}
            {% esi_fragment 'oxyan/headers/partials/goods-user-bar.html' with sessionid=True oscar_open_basket=True messages=messages request=request csrf_token=csrf_token user=user basket=basket num_unread_notifications=num_unread_notifications only %}
            {% block language_chooser %}{% endblock language_chooser %}
        </div>
    </nav>
</header>
{% endblock %}