{% load i18n ocyanjson %}

<div class="dropdown">
    <button class="dropdown-toggle nav-link" data-bs-toggle="dropdown" aria-label="Basket" title="{% trans "Basket button" %}">
        <i class="fa fa-shopping-cart-solid nav-icon" title="{% trans 'Basket' %}"></i>
        {% if request.basket.num_items %}<span class="icon-label">{{ request.basket.num_items }}</span>{% endif %}
    </button>

    <div class="dropdown-menu dropdown-menu-end">
        {% include "oxyan/headers/partials/basket.html" %}
    </div>
</div>