{% extends 'wagtail_content_page/content_page.html' %}
{% load wagtailcore_tags static %}

{% block title %}{% if page.get_meta_title %}{{ page.get_meta_title }}{% else %}{{ block.super }}{% endif %}{% if page.get_site.site_name %} - {{ page.get_site.site_name }}{% endif %}{% endblock %}

{% block content %}
<div class="container content-page-wrapper">
	{% include_block page.body %}
</div>
{% endblock %}
