

@font-face {
  font-family: 'Highbiza';
  src: url('../icons/icons.eot');
  src: url('../icons/icons.eot?#iefix') format('embedded-opentype'),
       url('../icons/icons.woff2') format('woff2'),
       url('../icons/icons.woff') format('woff'),
       url('../icons/icons.ttf') format('truetype'),
       url('../icons/icons.otf') format('opentype');
  font-weight: normal;
  font-style: normal;
  font-display: swap;
}




.fa {
    display: inline-block;
    font: normal normal normal 14px/1 'Highbiza';
    font-size: inherit;
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}


  .fa-lg {
      font-size: 1.33333333em;
      line-height: 0.75em;
      vertical-align: -15%;
  }

  .fa-2x {
      font-size: 2em;
  }

  .fa-3x {
      font-size: 3em;
  }

  .fa-4x {
      font-size: 4em;
  }

  .fa-5x {
      font-size: 5em;
  }



  .fa-fw {
      width: 1.28571429em;
      text-align: center;
  }



  .fa-ul {
      padding-left: 0;
      margin-left: 2.14285714em;
      list-style-type: none;
  }

  .fa-ul> li {
      position: relative;
  }

  .fa-li {
      position: absolute;
      left: -2.14285714em;
      width: 2.14285714em;
      top: 0.14285714em;
      text-align: center;
  }

  .fa-li.fa-lg {
      left: -1.85714286em;
  }



  .fa-border {
      padding: .2em .25em .15em;
      border: solid 0.08em #eeeeee;
      border-radius: .1em;
  }

  .pull-right {
      float: right;
  }

  .pull-left {
      float: left;
  }

  .fa.pull-left {
      margin-right: .3em;
  }

  .fa.pull-right {
      margin-left: .3em;
  }



  .fa-spin {
      -webkit-animation: fa-spin 2s infinite linear;
      animation: fa-spin 2s infinite linear;
  }

  .fa-pulse {
      -webkit-animation: fa-spin 1s infinite steps(8);
      animation: fa-spin 1s infinite steps(8);
  }

  @-webkit-keyframes fa-spin {
      0% {
          -webkit-transform: rotate(0deg);
          transform: rotate(0deg);
      }
      100% {
          -webkit-transform: rotate(359deg);
          transform: rotate(359deg);
      }
  }

  @keyframes fa-spin {
      0% {
          -webkit-transform: rotate(0deg);
          transform: rotate(0deg);
      }
      100% {
          -webkit-transform: rotate(359deg);
          transform: rotate(359deg);
      }
  }



  .fa-rotate-90 {
      filter: "progid: DXImageTransform.Microsoft.BasicImage(rotation=1)";
      -webkit-transform: rotate(90deg);
      -ms-transform: rotate(90deg);
      transform: rotate(90deg);
  }

  .fa-rotate-180 {
      filter: "progid: DXImageTransform.Microsoft.BasicImage(rotation=2)";
      -webkit-transform: rotate(180deg);
      -ms-transform: rotate(180deg);
      transform: rotate(180deg);
  }

  .fa-rotate-270 {
      filter: "progid: DXImageTransform.Microsoft.BasicImage(rotation=3)";
      -webkit-transform: rotate(270deg);
      -ms-transform: rotate(270deg);
      transform: rotate(270deg);
  }

  .fa-flip-horizontal {
      filter: "progid: DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
      -webkit-transform: scale(-1, 1);
      -ms-transform: scale(-1, 1);
      transform: scale(-1, 1);
  }

  .fa-flip-vertical {
      filter: "progid: DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
      -webkit-transform: scale(1, -1);
      -ms-transform: scale(1, -1);
      transform: scale(1, -1);
  }

  :root .fa-rotate-90,
  :root .fa-rotate-180,
  :root .fa-rotate-270,
  :root .fa-flip-horizontal,
  :root .fa-flip-vertical {
      filter: none;
  }



  .fa-stack {
      position: relative;
      display: inline-block;
      width: 2em;
      height: 2em;
      line-height: 2em;
      vertical-align: middle;
  }

  .fa-stack-1x,
  .fa-stack-2x {
      position: absolute;
      left: 0;
      width: 100%;
      text-align: center;
  }

  .fa-stack-1x {
      line-height: inherit;
  }

  .fa-stack-2x {
      font-size: 2em;
  }

  .fa-inverse {
      color: #ffffff;
  }



  .fa-star-solid:before {
      content: '\f001';
  }

  .fa-check:before {
      content: '\f003';
  }

  .fa-home:before {
      content: '\f005';
  }

  .fa-comment:before {
      content: '\f006';
  }

  .fa-phone:before {
      content: '\f008';
  }

  .fa-twitter:before {
      content: '\f009';
  }

  .fa-google-plus:before {
      content: '\f00b';
  }

  .fa-linkedin:before {
      content: '\f00d';
  }

  .fa-cart-arrow-down:before {
      content: '\f010';
  }

  .fa-youtube:before {
      content: '\f019';
  }

  .fa-check-fas:before {
      content: '\f01a';
  }

  .fa-trash:before {
      content: '\f01c';
  }

  .fa-envelope-open:before {
      content: '\f01d';
  }

  .fa-circle:before {
      content: '\f020';
  }

  .fa-filter:before {
      content: '\f021';
  }

  .fa-cloud:before {
      content: '\f024';
  }

  .fa-instagram:before {
      content: '\f025';
  }

  .fa-pinterest:before {
      content: '\f026';
  }

  .fa-facebook:before {
      content: '\f027';
  }

  .fa-whatsapp:before {
      content: '\f028';
  }

  .fa-envelope:before {
      content: '\f029';
  }

  .fa-globe:before {
      content: '\f02a';
  }

  .fa-truck:before {
      content: '\f030';
  }

  .fa-shopping-cart:before {
      content: '\f031';
  }

  .fa-chevron-down:before {
      content: '\f032';
  }

  .fa-chevron-left:before {
      content: '\f033';
  }

  .fa-chevron-right:before {
      content: '\f034';
  }

  .fa-chevron-up:before {
      content: '\f035';
  }

  .fa-user:before {
      content: '\f036';
  }

  .fa-clipboard-list:before {
      content: '\f037';
  }

  .fa-times:before {
      content: '\f038';
  }

  .fa-minus:before {
      content: '\f039';
  }

  .fa-plus:before {
      content: '\f03a';
  }

  .fa-bars:before {
      content: '\f03b';
  }

  .fa-heart:before {
      content: '\f03c';
  }

  .fa-lock-alt:before {
      content: '\f03d';
  }

  .fa-wallet:before {
      content: '\f03e';
  }

  .fa-search:before {
      content: '\f03f';
  }

  .fa-plus-circle:before {
      content: '\f040';
  }

  .fa-tags:before {
      content: '\f041';
  }

  .fa-receipt:before {
      content: '\f042';
  }

  .fa-times-circle:before {
      content: '\f043';
  }

  .fa-info-circle:before {
      content: '\f044';
  }

  .fa-exclamation:before {
      content: '\f045';
  }

  .fa-play:before {
      content: '\f046';
  }

  .fa-chevron-double-right:before {
      content: '\f047';
  }

  .fa-eye:before {
      content: '\f048';
  }

  .fa-clock:before {
      content: '\f049';
  }

  .fa-paper-plane:before {
      content: '\f04a';
  }

  .fa-chevron-double-left:before {
      content: '\f04b';
  }

  .fa-angle-left:before {
      content: '\f04c';
  }

  .fa-download:before {
      content: '\f04d';
  }

  .fa-layer-plus:before {
      content: '\f04e';
  }

  .fa-star:before {
      content: '\f04f';
  }

  .fa-star-half:before {
      content: '\f050';
  }

  .fa-star-half-solid:before {
      content: '\f051';
  }

  .fa-trash-alt:before {
      content: '\f052';
  }

  .fa-arrow-left:before {
      content: '\f053';
  }

  .fa-heart-solid:before {
      content: '\f054';
  }

  .fa-arrow-circle-right:before {
      content: '\f055';
  }

  .fa-pencil:before {
      content: '\f056';
  }

  .fa-inbox:before {
      content: '\f057';
  }

  .fa-info:before {
      content: '\f058';
  }

  .fa-exclamation-triangle:before {
      content: '\f059';
  }

  .fa-tag:before {
      content: '\f05a';
  }

  .fa-list:before {
      content: '\f05b';
  }

  .fa-sign-out:before {
      content: '\f05c';
  }

  .fa-info-square:before {
      content: '\f05d';
  }

  .fa-location:before {
      content: '\f05e';
  }

  .fa-sync-alt:before {
      content: '\f05f';
  }

  .fa-sync:before {
      content: '\f060';
  }

  .fa-map-marker-alt:before {
      content: '\f061';
  }

  .fa-long-arrow-right:before {
      content: '\f062';
  }

  .fa-angle-double-down:before {
      content: '\f063';
  }

  .fa-angle-double-right:before {
      content: '\f064';
  }

  .fa-angle-double-left:before {
      content: '\f065';
  }

  .fa-angle-double-up:before {
      content: '\f066';
  }

  .fa-chevron-double-down:before {
      content: '\f067';
  }

  .fa-chevron-double-up:before {
      content: '\f068';
  }

  .fa-users:before {
      content: '\f069';
  }

  .fa-check-circle:before {
      content: '\f06a';
  }

  .fa-th:before {
      content: '\f06b';
  }

  .fa-ruler:before {
      content: '\f06c';
  }

  .fa-question:before {
      content: '\f06d';
  }

  .fa-headphones:before {
      content: '\f06e';
  }

  .fa-shopping-bag:before {
      content: '\f06f';
  }

  .fa-minus-circle:before {
      content: '\f070';
  }

  .fa-eye-slash:before {
      content: '\f071';
  }

  .fa-leaf:before {
      content: '\f072';
  }

  .fa-box-open:before {
      content: '\f073';
  }

  .fa-fire:before {
      content: '\f074';
  }

  .fa-arrow-circle-left:before {
      content: '\f075';
  }

  .fa-arrow-circle-up:before {
      content: '\f076';
  }

  .fa-arrow-circle-down:before {
      content: '\f077';
  }

  .fa-shopping-cart-solid:before {
      content: '\f078';
  }

  .fa-sort-alpha-down:before {
      content: '\f079';
  }

  .fa-sort-numeric-down-alt:before {
      content: '\f07a';
  }

  .fa-user-solid:before {
      content: '\f07b';
  }

  .fa-lock-solid:before {
      content: '\f07c';
  }

  .fa-megaphone:before {
      content: '\f07d';
  }

  .fa-bell:before {
      content: '\f07e';
  }

  .fa-bell-solid:before {
      content: '\f07f';
  }

  .fa-thumbs-up:before {
      content: '\f080';
  }

  .fa-thumbs-down:before {
      content: '\f081';
  }

  .fa-thumbs-up-solid:before {
      content: '\f082';
  }

  .fa-thumbs-down-solid:before {
      content: '\f083';
  }

  .fa-cog:before {
      content: '\f084';
  }

  .fa-cog-solid:before {
      content: '\f085';
  }

  .fa-address-book:before {
      content: '\f086';
  }

  .fa-tags-solid:before {
      content: '\f087';
  }

  .fa-address-book-solid:before {
      content: '\f088';
  }

  .fa-paper-plane-solid:before {
      content: '\f089';
  }

  .fa-inbox-solid:before {
      content: '\f08a';
  }

  .fa-archive-solid:before {
      content: '\f08b';
  }

  .fa-long-arrow-left:before {
      content: '\f08c';
  }

  .fa-exchange:before {
      content: '\f08d';
  }

  .fa-directions-solid:before {
      content: '\f08e';
  }

  .fa-directions:before {
      content: '\f08f';
  }

  .fa-calendar-alt:before {
      content: '\f090';
  }

  .fa-sliders:before {
      content: '\f091';
  }

  .fa-angle-right:before {
      content: '\f092';
  }

  .fa-caret-down:before {
      content: '\f093';
  }

  .fa-caret-left:before {
      content: '\f094';
  }

  .fa-caret-right:before {
      content: '\f095';
  }

  .fa-caret-up:before {
      content: '\f096';
  }

  .fa-magnifying-glass-plus:before {
      content: '\f097';
  }

  .fa-magnifying-glass-minus:before {
      content: '\f098';
  }

  .fa-xmark:before {
      content: '\f099';
  }

  .fa-clipboard:before {
      content: '\f09a';
  }

  .fa-frown-o:before {
      content: '\f09b';
  }

  .fa-folder-open:before {
      content: '\f09c';
  }

  .fa-glass:before {
      content: '\f09d';
  }

  .fa-copy-regular:before {
      content: '\f09e';
  }

  .fa-share-from:before {
      content: '\f09f';
  }

  .fa-bag-shopping:before {
      content: '\f0a0';
  }

  .fa-cart-shopping-fast:before {
      content: '\f0a1';
  }

  .fa-calendar-days:before {
      content: '\f0a2';
  }

  .fa-mug-hot:before {
      content: '\f0a3';
  }

  .fa-rocket-launch:before {
      content: '\f0a4';
  }

  .fa-pause:before {
      content: '\f0a5';
  }

  .fa-user-secret:before {
      content: '\f0a6';
  }

  .fa-angle-up:before {
      content: '\f0a7';
  }

  .fa-angle-down:before {
      content: '\f0a8';
  }

  .fa-calendar-range:before {
      content: '\f0a9';
  }

  .fa-layer-group:before {
      content: '\f0aa';
  }

  .fa-badge-check:before {
      content: '\f0ab';
  }

  .fa-arrow-down:before {
      content: '\f0ac';
  }

  .fa-arrow-up:before {
      content: '\f0ad';
  }

  .fa-arrow-right:before {
      content: '\f0ae';
  }

  .fa-receipt-solid:before {
      content: '\f0af';
  }

  .fa-truck-solid:before {
      content: '\f0b0';
  }

  .fa-lock-alt-solid:before {
      content: '\f0b1';
  }

  .fa-earth-europe:before {
      content: '\f0b2';
  }

  .fa-earth-africa:before {
      content: '\f0b3';
  }

  .fa-letter-open:before {
      content: '\f0b4';
  }

  .fa-letter:before {
      content: '\f0b5';
  }

  .fa-arrow-down-arrow-up:before {
      content: '\f0b6';
  }

  .fa-cloud-arrow-up:before {
      content: '\f0b7';
  }

  .fa-cloud-arrow-up-solid:before {
      content: '\f0b8';
  }

  .fa-upload-solid:before {
      content: '\f0b9';
  }

  .fa-upload:before {
      content: '\f0ba';
  }

  .fa-download-solid:before {
      content: '\f0bb';
  }

  .fa-cloud-arrow-down-solid:before {
      content: '\f0bc';
  }

  .fa-cloud-arrow-down:before {
      content: '\f0bd';
  }

  .fa-list-check:before {
      content: '\f0be';
  }

  .fa-folder-solid:before {
      content: '\f0bf';
  }

  .fa-folder:before {
      content: '\f0c0';
  }

  .fa-spider-web:before {
      content: '\f0c1';
  }

  .fa-share-from-square:before {
      content: '\f0c2';
  }

  .fa-share:before {
      content: '\f0c3';
  }

  .fa-share-nodes:before {
      content: '\f0c4';
  }

  .fa-share-nodes-solid:before {
      content: '\f0c5';
  }

  .fa-needle:before {
      content: '\f0c6';
  }

  .fa-logout:before {
      content: '\f0c7';
  }

  .fa-twitter-x:before {
      content: '\f0c8';
  }

  .fa-tiktok:before {
      content: '\f0c9';
  }


.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0
}

.sr-only-focusable:active,
.sr-only-focusable:focus {
    position: static;
    width: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    clip: auto
}
