from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "readability")

variables = {
    "font-size-root": 1.2,
    "header-font-family": ["serif"],
    "font-family-base": "font-family-sans-serif",
}
