{% extends "oscar/customer/wishlists/wishlists_delete_product.html" %}
{% load i18n %}

{% block tabcontent %}
<form method="post">
    {% csrf_token %}
    <p>
{% blocktrans with product_name=object.get_title wishlist_name=wishlist.name %}Are you sure you want to delete {{ product_name }} from wish list {{ wishlist_name }}?{% endblocktrans %}
    </p>

    <div class="form-group">
        <button type="submit" class="btn btn-danger" data-loading-text="{% trans 'Removing...' %}">{% trans 'Remove' %}</button> {% trans 'or' %} <a href="{{ wishlist.get_absolute_url }}">{% trans 'cancel' %}</a>
    </div>
</form>
{% endblock tabcontent %}