{% load ocyan_thumbnail i18n %}

<div class="custom-simple-carousel">
    {% for slide in self %}
    <a class="item-link {% if not slide.url %}no-hover{% endif %}" href="{{slide.url}}">
        <div class="item">
            {% if forloop.first %}
            {% focuspoint_picture slide.image "175x175" %}
            {% else %}
            {% lazy_tns_focuspoint_picture slide.image "175x175" %}
            {% endif %}
        </div>
        {% if slide.name %}
            <span class="text-center slide-name">{{slide.name}}</span>
        {% endif %}
    </a>
    {% endfor %}
</div>