{% extends "checkout/partials/formblock.html" %}
{% load i18n %}

{% block panel_header %}
  <label class="paymentmethod control-label required{% if form.errors %} error{% endif %}">
      <h3>{% trans 'Payment method' %}</h3>
  </label>
{% endblock %}
{% block panel_body %}
      {% for field in form.hidden_fields %}
        {{ field }}
      {% endfor %}

      {% for field in form.visible_fields %}
        {% include "checkout/partials/payment_method_form_field.html" with field=field %}
      {% endfor %}
{% endblock %}
