{% load i18n static compress oxyan ocyan_main ocyanjson %}<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE|default:"en-gb" }}">
    <head>
        <title>{% block title %}{{ shop_name }} - {{ shop_tagline }}{% endblock %}</title>
        <!--
            Website made by Mandel. See mandelblog.com for inquiries.
            -->
        <meta http-equiv="content-type" content="text/html; charset=UTF-8">
        {% block theme_color %}<meta name="theme-color" content="{% get_oxyan_definition 'primary' %}">{% endblock %}
        <meta name="created" content="{% now "jS M Y h:i" %}">
        <meta name="description" content="{% block description %}{% endblock %}">
        <meta name="viewport" content="{% block viewport %}width=device-width{% endblock %}">

        {% block favicon %}
        <link rel="shortcut icon" href="{% static "oscar/favicon.ico" %}">
        {% endblock %}

        {% block head_imports %}

        {% compress css file styles %}
        <link rel="stylesheet" type="text/css" href="{% static 'css/external.css' %}">
        {% block oxyan_themes_bundle_css %}<link rel="stylesheet" type="text/css" href="{% static 'bundle.css' %}">{% endblock %}
        {% block base_css %}
        <link rel="stylesheet" type="text/x-scss" href="{% static 'scss/base.scss' %}">
        {% endblock %}

        {# Block where global CSS will go. #}
        {% block styles %}{% endblock %}
        {% endcompress %}

        {% block previewtheme %}
        {% ocyanjson "themes" "theme-switcher" as theme_switcher %}
        {% if theme_switcher and "previewtheme" in request.GET %}
        <link rel="stylesheet" type="text/css" href="{% url 'themes:preview-theme' request.GET.previewtheme %}">
        {% endif %}
        {% endblock %}

        {% compress css file extrastyles %}
        {# Additional CSS - specific to certain pages #}
        {% block extrastyles %}{% endblock %}
        {% endcompress %}

        {% block extrahead %}
        {% endblock %}

        {% block hreflang %}
        {% endblock %}

        {% endblock head_imports %}

        {% block uncompressed %}{% endblock %}
    </head>
    {% block body_wrapper %}
    <body id="{% block body_id %}{% endblock %}" class="{% block body_class %}{% endblock %}">
        {# Main content goes in this 'layout' block #}

        {% block layout %}

        {% block to_content_button %}
            <a class="btn btn-secondary hidelink" id="main_content_link" href="#skip_header" tabindex="2">
                {% trans "Ga naar inhoud" %}
            </a>
        {% endblock to_content_button %}

        {% block navbar %}{% endblock %}

        {% block content_wrapper %}
        <div id="main_content" tabindex="-1">
            {% block content %}
            {% endblock %}
        </div>
        {% endblock %}

        {% block footer %}{% endblock %}
        {% endblock %}



        {# Scripts loaded from a CDN. #}
        {% block cdn_scripts %}
        <script src="{% static 'jquery.min.js' %}"></script>
        {% endblock %}

        {# Local scripts #}
        <!-- sitewide scripts -->
        {% compress js file scripts  %}
        {% block oxyan_themes_bundle_js %}<script src="{% static 'bundle.js' %}"></script>{% endblock %}
        {% block scripts %}
        {% endblock %}
        {% endcompress %}

        {# Additional JS scripts #}
        <!-- page specific scripts -->
        {% compress js file extrascripts %}
        {% block extrascripts %}{% endblock %}
        {% endcompress %}

        {% optional_ai_assistant_widget %}

        {# Block for body onload functions #}
        <script type="text/javascript" nonce="{% nonce %}">
            $(function() {
                {% block onbodyload %}{% endblock %}
            });
        </script>

        {# Page meta-data - this is populated by the 'metadata' template context processor #}
    </body>
    {% endblock body_wrapper %}
</html>
