{% load styling_tags ocyan_main %}


<div class="modal fade popup_block" tabindex="-1" id="popupblock">
	<div class="modal-dialog modal-dialog-centered modal-dialog-scrollable modal-lg">
		<div class="modal-content">
			{% if self.header %}
			<div class="modal-header">
				<span class="h3 mb-0">{{ self.header }}</span>
			<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
			</div>
			{% else %}
			<button type="button" class="btn-close top-right" data-bs-dismiss="modal" aria-label="Close"></button>
			{% endif %}
			<div class="modal-body">
				{{self.body|convert_to_html}}
			</div>
		</div>
	</div>
	<script type="text/javascript" nonce="{% nonce %}">
		  setTimeout(function(){ $("#popupblock").modal('show'); }, 500);  
	</script>
</div>
