@mixin header_commerce_styles {
    header.commerce{
        background: $header-background;
        --header-accent: #{$gray-100};
        --header-color: #{$black};
        .navbar{
            padding-bottom: 0;
        }
        .search-wrapper{
            @media screen and (min-width: #{map-get($container-max-widths , lg)}){
                max-width: 20rem;
            }
            @media screen and (max-width: #{map-get($container-max-widths , lg)}){
                order: 5;
                padding-bottom: 0.5rem;
                .navbar-toggler {
                    display: none;
                }
            }
        }
        .dropdown-inner-header{
            font-weight: 600 !important;
            text-decoration: unset !important;
        }
        .dropdown-header{
            font-weight: 600 !important;
        }
        .page-menu-bar{
            @media screen and (min-width: #{map-get($container-max-widths , xl)}){
                padding-left: 0 !important;
                overflow: visible;
                overflow-x: visible !important;
                li{
                    &.dropdown{
                        &:not(:hover){
                            .dropdown-menu{
                                display: none;
                            }
                        }
                        &:hover{
                            display: flex !important;
                        }
                        .dropdown-menu{
                            position: absolute !important;
                            top: 100%;
                            background: $gray-100;
                            border: 0;
                            padding: 1rem;
                            border-top-left-radius: 0;
                            border-top-right-radius: 0;
                        }
                    }
                }
            }
            @media screen and (max-width: #{map-get($container-max-widths , xl)}){
                li{
                    &.dropdown{
                        .dropdown-menu{
                            display: none !important;
                        }
                    }
                }
            }
        }
        [data-bs-target="#menu_wrapper"]{
            order: 4;
        }
        & > .header-inner{
            & > .container{
                .navbar-brand{
                    margin-right: auto;
                }
            }
        }
        .dropdown-toggle.left-toggle{
            @media screen and (max-width: #{map-get($container-max-widths , lg)}){
                display: none !important;
            }
        }
        #menu_wrapper{
            position: absolute;
            width: 100%;
            left: 0;
            top: 100%;
            background: white;
            z-index: 999;

            &.show, &.collapsing{
                .container {
                    display: flex;
                }
            }

            &>.container {
                background-color:white;
                flex-direction: column;
                z-index: 910;
            }

            .promotion_wrapper{
                width: 25%;
                display: flex;
                flex-direction: column;
                .above {
                    display: flex;
                    flex-direction: column;
                    justify-content: center;
                    margin-top: 5vh;
                    height:55vh;
                    &>.row {
                        margin: 0!important;
                        justify-content: space-between;
                        .item {
                            margin: .5rem 0 !important;
                            padding: 0;
                            width: 5rem;
                            height: 5rem;
                            border-radius: 50%;
                            display: flex;
                            align-items: center;
                            justify-content: center;
                            object-fit: cover;
                            overflow: hidden;
                            a {
                                width: 5rem;
                                height: 5rem;
                                margin: 0;
                            }
                            img {
                                width: 5rem;
                                height: 5rem;
                            }
                        }
                    }
                }
            }
            .menu_inner {
                width: 100% !important;
                margin: 1rem 0 !important;
                & > li {
                    .dropdown-header{
                        display: flex;
                    }
                    &:first-child{
                        margin-top: 0 !important;
                    }
                    a{
                        color: black !important;
                        font-weight: 400;
                    }
                }
                .dropdown-menu {
                    display: flex !important;
                    flex-direction: column;
                }

                & > .nav-item{
                    width: 33.333333% !important;
                    font-size: 18px;
                    margin: 0px;

                    & > a{
                        padding: .5rem 0;
                    }
                    
                    a {
                        color: black;
                        display: flex;
                        align-items: center;
                    }


                    & > .dropdown-menu {
                        border: unset;
                        list-style: none;
                        padding: 0rem;

                        a {
                            color: ocyancolor("black");
                            padding: 0rem;
                            @media screen and (max-width: 768px){
                                padding: .25rem 0;
                            }

                            &:before {
                                content: none;
                            }
                            &:after {
                                content: none;
                            }
                        }
                    }
                }
            }
        }
        .subheader{
            background: $gray-100;
            .wrap_subheader{
                @media screen and (max-width: #{map-get($container-max-widths , lg)}){
                    display: block;
                    padding: 0;
                }
            }
            .navbar-collapse{
                flex-basis: auto !important;
                display: flex !important;
                padding: .5rem 0;
                .page-menu-bar{
                    margin-top: 0 !important;
                    margin-bottom: 0;
                    padding: 0 0.75rem;
                    overflow-x: scroll;
                    -ms-overflow-style: none;
                    scrollbar-width: none;
                    ul{
                        display: flex;
                        flex-direction: row;
                        .nav-item {
                            text-align: left;
                            display: list-item;
                            white-space: nowrap;
                            a{
                                background: var(--header-accent);
                                color: var(--header-color);
                                text-decoration: unset;
                                border-radius: 30px;
                                margin-left: 0 !important;
                                margin-right: .5rem;
                                padding: .25rem .5rem;
                                font-weight: 600;
                                display: block;
                            }
                        }
                    }
                }
                .dropdown{
                    .dropdown-toggle{
                        background: var(--header-accent);
                        color: var(--header-color);
                        text-decoration: unset;
                        border-radius: 30px;
                        margin-left: 0 !important;
                        margin-right: .5rem;
                        padding: .25rem .5rem;
                        font-weight: 600;
                        display: block;
                        &:after{
                            content: "\f0a8";
                            border: 0;
                            font-family: "Highbiza";
                            vertical-align: middle;
                        }
                    }
                }
                #menu_wrapper{
                    // Desktop menu
                    @media screen and (min-width: #{map-get($container-max-widths , lg)}){
                        .mobile-header{
                            display: none;
                        }
                        .menu_inner{
                            display: flex;
                            flex-wrap: nowrap;
                            flex-direction: column;
                            align-items: flex-start;
                            position: relative;
                            overflow: auto;
                            min-height: 60vh;
                            margin-bottom: 1rem;
                            width: 100%;
                            padding: 0 !important;
                            border-radius: 0rem;
                            list-style: none;
                            margin-top: 3rem !important;
                            &:before, &:after{
                                content: "";
                                border-left: 1px solid $gray-100;
                                position: absolute;
                                top: 0;
                                left: 33.33333333%;
                                min-height: 100%;
                                z-index: 999999999;
                                pointer-events: none;
                            }
                            &:after{
                                left: 66.6666666666%;
                            }
                            .dropdown-header{
                                margin-top: 0 !important;
                                padding: .5rem 1rem !important;
                                color: black;
                                font-size: 1.2rem;
                                font-weight: 500;
                            }
                            & > li{
                                margin-top: 1rem !important;                            
                            }
                            li.nav-item{
                                margin-top: 0 !important;
                                position: unset !important;
                                a.nav-link{
                                    display: flex;
                                    align-items: center;
                                    padding: .25rem 1rem !important;
                                    margin-right: 0 !important;
                                    width: 100%;
                                    word-break: break-word;
                                    img{
                                        margin-right: 1rem;
                                        border-radius: 100%;
                                        width: 2rem;
                                        height: 2rem;
                                        object-fit: cover;
                                    }
                                    &:before{
                                        content: "";
                                        width: 1px;
                                        height: 40px;
                                        display: block;
                                    }
                                    &:after{
                                        font-family: 'Highbiza';
                                        content: "\f034";
                                        display: inline-block;
                                        padding-left: .5rem;
                                        margin-left: auto;
                                        color: $gray-900;
                                        font-size: 1.25rem;
                                        opacity: 0;
                                    }
                                }
                                ul.dropdown-menu{
                                    position: absolute;
                                    top: 0;
                                    left: 33.333333%;
                                    width: 33.333333%;
                                    height: unset;
                                    display: none !important;
                                    padding: 0 !important;
                                    padding-bottom: 10rem !important;
                                    background: white !important;
                                    min-height: 100%;
                                    li.nav-item{
                                        a.nav-link{
                                            padding: .5rem 0;
                                            color: black !important;
                                        }
                                        & > ul.dropdown-menu{
                                            left: calc(100%);
                                            width: 100%;
                                            border: 0;
                                            height: 100%;
                                        }
                                    }
                                }
                                &.has-children{
                                    cursor: default;
                                    &:hover{
                                        & > a.nav-link{
                                            background: $gray-100;
                                            &:after{
                                                opacity: 1;
                                            }
                                        }
                                        & > ul.dropdown-menu{
                                            display: block !important;
                                        }
                                    }
                                }
                                &:not(.has-children){
                                    &:hover{
                                        & > a.nav-link{
                                            background: $gray-100;
                                            color: var(--header-accent);
                                        }
                                    }
                                }
                            }
                        }
                    }
                    // Mobile menu
                    @media screen and (max-width: #{map-get($container-max-widths , lg)}){
                        & > .container.p-0{
                            overflow-y: auto;
                            overflow-x: hidden;
                            height: 100vh;
                            padding-top: 1rem !important;
                            padding-bottom: 5rem !important;
                        }
                        &:not(.show){
                            transform: translateX(100%);
                        }
                        &.show{
                            transform: translateX(0%);
                        }
                        transition: .3s ease transform;
                        position: fixed;
                        top: 0 !important;
                        left: 0;
                        width: 100%;
                        height: calc((var(--vh, 1vh) * 100) - 53px);
                        min-height: 100vh;
                        background: white;
                        z-index: 999999999;
                        .mobile-header{
                            display: flex;
                            align-items: center;
                            justify-content: space-between;
                            flex-wrap: wrap;
                            padding: 1rem;
                            background: transparent;
                            position: fixed;
                            top: 0;
                            left: 0;
                            width: 100%;
                            z-index: 9999999999;
                            pointer-events: none;
                            button{
                                margin: 0 !important;
                                margin-left: auto !important;
                                padding: 0;
                                display: flex;
                                align-items: center;
                                justify-content: center;
                                width: 2rem;
                                height: 2rem;
                                color: $gray-900;
                                font-size: 1.8rem;
                                background: white;
                                pointer-events: all;
                            }
                        }
                        .menu_inner{
                            display: flex;
                            flex-wrap: wrap;
                            padding: 1rem 0;
                            position: relative;
                            @media screen and (max-width: #{map-get($container-max-widths , lg)}){
                                height: auto !important;
                            }
                            & > .dropdown-header{
                                font-size: 1.2rem;
                                padding: .5rem 1rem !important;
                                margin-left: 1rem;
                                color: black;
                                font-weight: 500;
                                position: relative;
                                i{
                                    display: flex;
                                    flex-direction: column;
                                    justify-content: center;
                                }
                                &:before{
                                    content: "";
                                    position: absolute;
                                    top: 50%;
                                    left: 0;
                                    transform: translateY(-50%);
                                    border-left: 3px solid var(--header-accent);
                                    height: 1rem;
                                }
                            }
                            li.nav-item{
                                position: unset !important;
                                width: 100% !important;
                                & > a.nav-link{
                                    padding: 1rem;
                                    display: flex;
                                    align-items: center;
                                    font-size: 1.2rem;
                                    border-bottom: 1px solid $gray-100;
                                    img{
                                        width: 60px;
                                        height: 60px;
                                        border-radius: 100%;
                                        margin-right: .75rem;
                                        object-fit: cover;
                                    }
                                }
                                &.has-children{
                                    & > a.nav-link{
                                        &:after{
                                            font-family: 'Highbiza';
                                            content: "\f034";
                                            display: inline-block;
                                            padding-left: .5rem;
                                            margin-left: auto;
                                            color: black;
                                            font-size: 1.5rem;
                                        }
                                    }
                                }
                                & > ul.dropdown-menu, & > ul.dropdown-menu li ul.dropdown-menu{
                                    position: absolute;
                                    top: 0;
                                    left: 0;
                                    width: 100vw;
                                    height: 100%;
                                    overflow: auto;
                                    overflow-x: hidden;
                                    padding: 0;
                                    padding-top: 0;
                                    border: 0;
                                    transition: .3s ease;
                                    background: white;
                                    scroll-behavior: smooth;
                                    padding-bottom: 30rem !important;
                                    .dropdown-header{
                                        padding: 1rem 1.5rem !important;
                                        color: black;
                                        font-size: 1.2rem;
                                        font-weight: 500;
                                        background: $gray-100;
                                        display: flex;
                                        align-items: center;
                                    }
                                    &:not(.open){
                                        transform: translateX(100%);
                                    }
                                    &.open{
                                        transform: translateX(0%);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}