{% load i18n %}
{% load product_tags %}

{% with products_sliced=products|slice:":6" %}
{% if products_sliced %}
<div class="recently-viewed-products">
    <div class="sub-header">
        <h3>{% trans 'Products you recently viewed' %}</h3>
    </div>
    <div class="row">
        {% for product in products_sliced %}
        <div class="col-6 recently_viewed_product">{% include "oscar/catalogue/partials/product.html" with product=product priceonly=True %}</div>
        {% endfor %}
    </div>
</div>
{% endif %}
{% endwith %}