{% extends "layout.html" %}
{% load i18n %}

{% block content %}
<section class="privacy-wrapper">
	<div class="container">
		<div class="row">
			<div class="col-xl-5 col-lg-7 col-md-8 mx-auto">
				<div class="login-wrapper">
					<div class="login-header">{% trans "For this page you need a password" %}</div>
					<form action="{{ action_url }}" method="POST">
					    {% csrf_token %}
					    <div class="icon_wrapper password">
			        		{% include "oscar/partials/form_field.html" with field=form.password nolabel=True placeholder=form.password.label %}
			        	</div>
					    {% for field in form.hidden_fields %}
				        {{ field }}
					    {% endfor %}
					    <div class="login-footer">
					    	<a href="/">{% trans "Back to homepage" %}</a>
			    			<button type="submit" value="Continue" class="btn btn-primary">{% trans "Continue" %}</button>
			    		</div>
					</form>
				</div>
			</div>
		</div>
	</div>
</section>
{% endblock %}