{% extends "errors.html" %}
{% load i18n %}
{% block title %}404 error{% endblock %}

{% block error_header %}404{% endblock %}
{% block error_sub_header %}{% trans "Oops, something went wrong." %}{% endblock %}
{% block error_body %}
<div class="button-wrapper">
  <a class="btn btn-outline-dark" onclick="javascript:history.go(-1);">{% trans 'Return to previous page' %}</a>
  <a class="btn btn-dark" href="/">{% trans "Go to homepage" %}</a>
</div>
{% endblock %}