from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "carbasa")

variables = {
    "border-radius": 0.75,
    "row-spacer": "4",
    "font-weight-normal": 100,
    "font-weight-bold": 800,
    "font-weight-headers": 400,
}
