{% load reviews_tags %}
{% load i18n %}


{% if product.rating != None %}
<div class="product-rating {% if product.rating != None %}{{ product.rating|as_stars }}{% else %}none{% endif %} stars-{{ product.rating }}">
    {% include "oscar/catalogue/reviews/partials/stars.html" with rating=product.rating %}
    <span class="product-rating-count">
        <small>
            <a href="{% url 'catalogue:reviews-list' product_slug=product.slug product_pk=product.id %}">
{% blocktrans count product.num_approved_reviews as num_reviews %}{{ num_reviews }} customer review{% plural %}{{ num_reviews }} customer reviews{% endblocktrans %}
            </a>
        </small>
    </span>
</div>
{% endif %}