<div class="payment-methods {% if field.errors %}error{% endif %}">
    {{ field.errors }}
    {% for payment_method in field %}
        <label class="d-block" for="{{payment_method.data.attrs.id}}">
        	<div class="label-text">
            	<input type="radio" name="{{payment_method.data.name}}" value="{{payment_method.data.value}}" id="{{payment_method.data.attrs.id}}" {% if payment_method.data.attrs.required %} required {% endif %}{% if payment_method.data.attrs.checked %} checked {% endif %}>
            	<span>{{payment_method.data.label}}</span>
            </div>
            <span name="{{payment_method.data.value}}" class="payment-image">&nbsp;</span>
        </label>
    {% endfor %}
</div>