{# Deze template extend niet van oscar dit hoort zo #}
{% load ocyan_thumbnail wagtailsettings_tags i18n %}
{% get_settings %}

{% with logo=settings.ocyan_plugin_wagtail.OcyanSettings.logo %}
{% with logo_alt=settings.ocyan_plugin_wagtail.OcyanSettings.logo_alt %}
{% trans "Website logo" as default_logo_alt %}
{% if big %}
{% with logo.focal_point_height|default:600|stringformat:"i" as logo_height %}
{% with logo.focal_point_width|default:600|stringformat:"ix"|add:logo_height as logo_size %}
<a class="navbar-brand" title="{% trans "Website logo and home page navigation" %}" href="{% url 'wagtail_serve' '' %}"><span class="logo big_brand">{% picture logo.file logo_size format="PNG" alt=logo_alt|default:default_logo_alt classes="" upscale=False %}</span></a>
{% endwith %}
{% endwith %}
{% else %}
{% with logo.focal_point_height|default:300|stringformat:"i" as logo_height %}
{% with logo.focal_point_width|default:300|stringformat:"ix"|add:logo_height as logo_size %}
<a class="navbar-brand" title="{% trans "Website logo and home page navigation" %}" href="{% url 'wagtail_serve' '' %}">{% block brand_title %}<span class="logo">{% picture logo.file logo_size format="PNG" alt=logo_alt|default:default_logo_alt classes="" upscale=False %}</span>{% endblock %}</a>
{% endwith %}
{% endwith %}
{% endif %}
{% endwith %}
{% endwith %}
